"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2
import bilireq.grpc.protos.bilibili.pagination.pagination_pb2
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BizTypeNone: _BizType.ValueType  # 0
    """"""
    BizTypeFollowVideo: _BizType.ValueType  # 1
    """追番追剧"""
    BizTypeReserveActivity: _BizType.ValueType  # 2
    """预约活动"""
    BizTypeJumpLink: _BizType.ValueType  # 3
    """跳转链接"""
    BizTypeFavSeason: _BizType.ValueType  # 4
    """收藏合集"""
    BizTypeReserveGame: _BizType.ValueType  # 5
    """预约游戏"""

class BizType(_BizType, metaclass=_BizTypeEnumTypeWrapper):
    """业务类型"""

BizTypeNone: BizType.ValueType  # 0
""""""
BizTypeFollowVideo: BizType.ValueType  # 1
"""追番追剧"""
BizTypeReserveActivity: BizType.ValueType  # 2
"""预约活动"""
BizTypeJumpLink: BizType.ValueType  # 3
"""跳转链接"""
BizTypeFavSeason: BizType.ValueType  # 4
"""收藏合集"""
BizTypeReserveGame: BizType.ValueType  # 5
"""预约游戏"""
global___BizType = BizType

class _Category:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CategoryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Category.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CategoryUnknown: _Category.ValueType  # 0
    """"""
    CategorySeason: _Category.ValueType  # 1
    """"""

class Category(_Category, metaclass=_CategoryEnumTypeWrapper):
    """"""

CategoryUnknown: Category.ValueType  # 0
""""""
CategorySeason: Category.ValueType  # 1
""""""
global___Category = Category

class _DescType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DescTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DescType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DescTypeUnknown: _DescType.ValueType  # 0
    """占位"""
    DescTypeText: _DescType.ValueType  # 1
    """文本"""
    DescTypeAt: _DescType.ValueType  # 2
    """@"""

class DescType(_DescType, metaclass=_DescTypeEnumTypeWrapper):
    """枚举-文本类型"""

DescTypeUnknown: DescType.ValueType  # 0
"""占位"""
DescTypeText: DescType.ValueType  # 1
"""文本"""
DescTypeAt: DescType.ValueType  # 2
"""@"""
global___DescType = DescType

class _ECode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ECodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ECode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT: _ECode.ValueType  # 0
    """正常"""
    CODE404: _ECode.ValueType  # 1
    """稿件被UP主删除"""

class ECode(_ECode, metaclass=_ECodeEnumTypeWrapper):
    """错误代码"""

DEFAULT: ECode.ValueType  # 0
"""正常"""
CODE404: ECode.ValueType  # 1
"""稿件被UP主删除"""
global___ECode = ECode

class _MaterialSource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MaterialSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MaterialSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Default: _MaterialSource.ValueType  # 0
    """"""
    BiJian: _MaterialSource.ValueType  # 1
    """必剪"""

class MaterialSource(_MaterialSource, metaclass=_MaterialSourceEnumTypeWrapper):
    """"""

Default: MaterialSource.ValueType  # 0
""""""
BiJian: MaterialSource.ValueType  # 1
"""必剪"""
global___MaterialSource = MaterialSource

class _OperationCardType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OperationCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OperationCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CardTypeNone: _OperationCardType.ValueType  # 0
    """"""
    CardTypeStandard: _OperationCardType.ValueType  # 1
    """标准卡"""
    CardTypeSkip: _OperationCardType.ValueType  # 2
    """原跳转卡"""

class OperationCardType(_OperationCardType, metaclass=_OperationCardTypeEnumTypeWrapper):
    """卡片样式"""

CardTypeNone: OperationCardType.ValueType  # 0
""""""
CardTypeStandard: OperationCardType.ValueType  # 1
"""标准卡"""
CardTypeSkip: OperationCardType.ValueType  # 2
"""原跳转卡"""
global___OperationCardType = OperationCardType

class _PayState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PayStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PayState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PayStateUnknown: _PayState.ValueType  # 0
    """"""
    PayStateActive: _PayState.ValueType  # 1
    """"""

class PayState(_PayState, metaclass=_PayStateEnumTypeWrapper):
    """"""

PayStateUnknown: PayState.ValueType  # 0
""""""
PayStateActive: PayState.ValueType  # 1
""""""
global___PayState = PayState

class _PlayerCardType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayerCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayerCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PlayerCardTypeNone_VALUE: _PlayerCardType.ValueType  # 0
    """"""
    PlayerCardTypeAttention_VALUE: _PlayerCardType.ValueType  # 1
    """关注卡"""
    PlayerCardTypeOperation_VALUE: _PlayerCardType.ValueType  # 2
    """运营卡"""
    PlayerCardTypeContract_VALUE: _PlayerCardType.ValueType  # 3
    """契约卡"""

class PlayerCardType(_PlayerCardType, metaclass=_PlayerCardTypeEnumTypeWrapper):
    """卡片类型"""

PlayerCardTypeNone_VALUE: PlayerCardType.ValueType  # 0
""""""
PlayerCardTypeAttention_VALUE: PlayerCardType.ValueType  # 1
"""关注卡"""
PlayerCardTypeOperation_VALUE: PlayerCardType.ValueType  # 2
"""运营卡"""
PlayerCardTypeContract_VALUE: PlayerCardType.ValueType  # 3
"""契约卡"""
global___PlayerCardType = PlayerCardType

class _PremiereState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PremiereStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PremiereState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    premiere_none: _PremiereState.ValueType  # 0
    """"""
    premiere_before: _PremiereState.ValueType  # 1
    """"""
    premiere_in: _PremiereState.ValueType  # 2
    """"""
    premiere_after: _PremiereState.ValueType  # 3
    """"""

class PremiereState(_PremiereState, metaclass=_PremiereStateEnumTypeWrapper):
    """"""

premiere_none: PremiereState.ValueType  # 0
""""""
premiere_before: PremiereState.ValueType  # 1
""""""
premiere_in: PremiereState.ValueType  # 2
""""""
premiere_after: PremiereState.ValueType  # 3
""""""
global___PremiereState = PremiereState

class _SeasonType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SeasonTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SeasonType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unknown: _SeasonType.ValueType  # 0
    """"""
    Base: _SeasonType.ValueType  # 1
    """"""
    Good: _SeasonType.ValueType  # 2
    """"""

class SeasonType(_SeasonType, metaclass=_SeasonTypeEnumTypeWrapper):
    """"""

Unknown: SeasonType.ValueType  # 0
""""""
Base: SeasonType.ValueType  # 1
""""""
Good: SeasonType.ValueType  # 2
""""""
global___SeasonType = SeasonType

class _TabOtype:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TabOtypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TabOtype.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UnknownOtype: _TabOtype.ValueType  # 0
    """未知类型"""
    URL: _TabOtype.ValueType  # 1
    """url链接"""
    TopicNA: _TabOtype.ValueType  # 2
    """native话题活动"""
    CmURI: _TabOtype.ValueType  # 3
    """广告url"""

class TabOtype(_TabOtype, metaclass=_TabOtypeEnumTypeWrapper):
    """TAB跳转类型"""

UnknownOtype: TabOtype.ValueType  # 0
"""未知类型"""
URL: TabOtype.ValueType  # 1
"""url链接"""
TopicNA: TabOtype.ValueType  # 2
"""native话题活动"""
CmURI: TabOtype.ValueType  # 3
"""广告url"""
global___TabOtype = TabOtype

class _TabStyle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TabStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TabStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UnknownStyle: _TabStyle.ValueType  # 0
    """未知样式"""
    Text: _TabStyle.ValueType  # 1
    """文字样式"""
    Pic: _TabStyle.ValueType  # 2
    """图片样式"""

class TabStyle(_TabStyle, metaclass=_TabStyleEnumTypeWrapper):
    """TAB样式"""

UnknownStyle: TabStyle.ValueType  # 0
"""未知样式"""
Text: TabStyle.ValueType  # 1
"""文字样式"""
Pic: TabStyle.ValueType  # 2
"""图片样式"""
global___TabStyle = TabStyle

@typing_extensions.final
class ActivityResource(google.protobuf.message.Message):
    """活动页资源包"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOD_POOL_NAME_FIELD_NUMBER: builtins.int
    MOD_RESOURCE_NAME_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    SELECTED_BG_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    LIGHT_TEXT_COLOR_FIELD_NUMBER: builtins.int
    DARK_TEXT_COLOR_FIELD_NUMBER: builtins.int
    DIVIDER_COLOR_FIELD_NUMBER: builtins.int
    mod_pool_name: builtins.str
    """mod资源池名称"""
    mod_resource_name: builtins.str
    """mod资源名称"""
    bg_color: builtins.str
    """背景色"""
    selected_bg_color: builtins.str
    """选中背景色"""
    text_color: builtins.str
    """文字颜色"""
    light_text_color: builtins.str
    """浅字色"""
    dark_text_color: builtins.str
    """深字色"""
    divider_color: builtins.str
    """分割线色"""
    def __init__(
        self,
        *,
        mod_pool_name: builtins.str = ...,
        mod_resource_name: builtins.str = ...,
        bg_color: builtins.str = ...,
        selected_bg_color: builtins.str = ...,
        text_color: builtins.str = ...,
        light_text_color: builtins.str = ...,
        dark_text_color: builtins.str = ...,
        divider_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "dark_text_color", b"dark_text_color", "divider_color", b"divider_color", "light_text_color", b"light_text_color", "mod_pool_name", b"mod_pool_name", "mod_resource_name", b"mod_resource_name", "selected_bg_color", b"selected_bg_color", "text_color", b"text_color"]) -> None: ...

global___ActivityResource = ActivityResource

@typing_extensions.final
class ActivitySeason(google.protobuf.message.Message):
    """大型活动合集"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARC_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    OWNER_EXT_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    ELEC_RANK_FIELD_NUMBER: builtins.int
    HISTORY_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    HONOR_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    UGC_SEASON_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    SUPPORT_DISLIKE_FIELD_NUMBER: builtins.int
    OPERATION_RELATE_FIELD_NUMBER: builtins.int
    ACTIVITY_RESOURCE_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    PLAYER_ICON_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    CM_CONFIG_FIELD_NUMBER: builtins.int
    TF_PANEL_CUSTOMIZED_FIELD_NUMBER: builtins.int
    ARGUE_MSG_FIELD_NUMBER: builtins.int
    ECODE_FIELD_NUMBER: builtins.int
    CUSTOM_CONFIG_FIELD_NUMBER: builtins.int
    BADGE_URL_FIELD_NUMBER: builtins.int
    DESC_V2_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    ARC_EXTRA_FIELD_NUMBER: builtins.int
    REPLY_PREFACE_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Arc:
        """稿件信息"""
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ViewPage]:
        """分P信息"""
    @property
    def owner_ext(self) -> global___OnwerExt:
        """("OnwerExt"为源码中拼写错误)"""
    @property
    def req_user(self) -> global___ReqUser:
        """稿件用户操作状态"""
    @property
    def elec_rank(self) -> global___ElecRank:
        """充电排行"""
    @property
    def history(self) -> global___History:
        """历史观看进度"""
    bvid: builtins.str
    """稿件bvid"""
    @property
    def honor(self) -> global___Honor:
        """获得荣誉信息"""
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """联合投稿成员列表"""
    @property
    def ugc_season(self) -> global___UgcSeason:
        """UGC视频合集信息"""
    @property
    def tab(self) -> global___Tab:
        """播放页定制tab"""
    @property
    def rank(self) -> global___Rank:
        """排行榜"""
    @property
    def order(self) -> global___Order:
        """预约模块"""
    support_dislike: builtins.bool
    """是否支持点踩"""
    @property
    def operation_relate(self) -> global___OperationRelate:
        """相关推荐(运营配置+AI推荐)"""
    @property
    def activity_resource(self) -> global___ActivityResource:
        """活动页资源包"""
    short_link: builtins.str
    """短链接"""
    @property
    def label(self) -> global___Label:
        """标签"""
    @property
    def dislike(self) -> global___Dislike:
        """不感兴趣原因"""
    @property
    def player_icon(self) -> global___PlayerIcon:
        """播放图标动画配置档"""
    share_subtitle: builtins.str
    """分享副标题(已观看xxx次)"""
    @property
    def cm_config(self) -> global___CMConfig:
        """广告配置"""
    @property
    def tf_panel_customized(self) -> global___TFPanelCustomized:
        """免流面板定制"""
    argue_msg: builtins.str
    """争议信息"""
    ecode: global___ECode.ValueType
    """错误码
    DEFAULT:正常 CODE404:视频被UP主删除
    """
    @property
    def custom_config(self) -> global___CustomConfig:
        """404页信息"""
    badge_url: builtins.str
    """评论样式"""
    @property
    def desc_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DescV2]:
        """稿件简介v2"""
    @property
    def config(self) -> global___Config:
        """"""
    @property
    def online(self) -> global___Online:
        """"""
    @property
    def arc_extra(self) -> global___ArcExtra:
        """"""
    @property
    def reply_preface(self) -> global___ReplyStyle:
        """"""
    def __init__(
        self,
        *,
        arc: bilibili.app.archive.v1.archive_pb2.Arc | None = ...,
        pages: collections.abc.Iterable[global___ViewPage] | None = ...,
        owner_ext: global___OnwerExt | None = ...,
        req_user: global___ReqUser | None = ...,
        elec_rank: global___ElecRank | None = ...,
        history: global___History | None = ...,
        bvid: builtins.str = ...,
        honor: global___Honor | None = ...,
        staff: collections.abc.Iterable[global___Staff] | None = ...,
        ugc_season: global___UgcSeason | None = ...,
        tab: global___Tab | None = ...,
        rank: global___Rank | None = ...,
        order: global___Order | None = ...,
        support_dislike: builtins.bool = ...,
        operation_relate: global___OperationRelate | None = ...,
        activity_resource: global___ActivityResource | None = ...,
        short_link: builtins.str = ...,
        label: global___Label | None = ...,
        dislike: global___Dislike | None = ...,
        player_icon: global___PlayerIcon | None = ...,
        share_subtitle: builtins.str = ...,
        cm_config: global___CMConfig | None = ...,
        tf_panel_customized: global___TFPanelCustomized | None = ...,
        argue_msg: builtins.str = ...,
        ecode: global___ECode.ValueType = ...,
        custom_config: global___CustomConfig | None = ...,
        badge_url: builtins.str = ...,
        desc_v2: collections.abc.Iterable[global___DescV2] | None = ...,
        config: global___Config | None = ...,
        online: global___Online | None = ...,
        arc_extra: global___ArcExtra | None = ...,
        reply_preface: global___ReplyStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity_resource", b"activity_resource", "arc", b"arc", "arc_extra", b"arc_extra", "cm_config", b"cm_config", "config", b"config", "custom_config", b"custom_config", "dislike", b"dislike", "elec_rank", b"elec_rank", "history", b"history", "honor", b"honor", "label", b"label", "online", b"online", "operation_relate", b"operation_relate", "order", b"order", "owner_ext", b"owner_ext", "player_icon", b"player_icon", "rank", b"rank", "reply_preface", b"reply_preface", "req_user", b"req_user", "tab", b"tab", "tf_panel_customized", b"tf_panel_customized", "ugc_season", b"ugc_season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_resource", b"activity_resource", "arc", b"arc", "arc_extra", b"arc_extra", "argue_msg", b"argue_msg", "badge_url", b"badge_url", "bvid", b"bvid", "cm_config", b"cm_config", "config", b"config", "custom_config", b"custom_config", "desc_v2", b"desc_v2", "dislike", b"dislike", "ecode", b"ecode", "elec_rank", b"elec_rank", "history", b"history", "honor", b"honor", "label", b"label", "online", b"online", "operation_relate", b"operation_relate", "order", b"order", "owner_ext", b"owner_ext", "pages", b"pages", "player_icon", b"player_icon", "rank", b"rank", "reply_preface", b"reply_preface", "req_user", b"req_user", "share_subtitle", b"share_subtitle", "short_link", b"short_link", "staff", b"staff", "support_dislike", b"support_dislike", "tab", b"tab", "tf_panel_customized", b"tf_panel_customized", "ugc_season", b"ugc_season"]) -> None: ...

global___ActivitySeason = ActivitySeason

@typing_extensions.final
class AddContractReq(google.protobuf.message.Message):
    """点击签订契约-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""
    up_mid: builtins.int
    """UP主mid"""
    spmid: builtins.str
    """当前页面spm"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        up_mid: builtins.int = ...,
        spmid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "spmid", b"spmid", "up_mid", b"up_mid"]) -> None: ...

global___AddContractReq = AddContractReq

@typing_extensions.final
class AdInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATIVE_ID_FIELD_NUMBER: builtins.int
    CREATIVE_TYPE_FIELD_NUMBER: builtins.int
    CREATIVE_CONTENT_FIELD_NUMBER: builtins.int
    AD_CB_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    creative_id: builtins.int
    """"""
    creative_type: builtins.int
    """"""
    @property
    def creative_content(self) -> global___CreativeContent:
        """"""
    ad_cb: builtins.str
    """"""
    card_type: builtins.int
    """"""
    extra: builtins.bytes
    """"""
    def __init__(
        self,
        *,
        creative_id: builtins.int = ...,
        creative_type: builtins.int = ...,
        creative_content: global___CreativeContent | None = ...,
        ad_cb: builtins.str = ...,
        card_type: builtins.int = ...,
        extra: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creative_content", b"creative_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_cb", b"ad_cb", "card_type", b"card_type", "creative_content", b"creative_content", "creative_id", b"creative_id", "creative_type", b"creative_type", "extra", b"extra"]) -> None: ...

global___AdInfo = AdInfo

@typing_extensions.final
class ArcExtra(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARC_PUB_LOCATION_FIELD_NUMBER: builtins.int
    arc_pub_location: builtins.str
    """"""
    def __init__(
        self,
        *,
        arc_pub_location: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_pub_location", b"arc_pub_location"]) -> None: ...

global___ArcExtra = ArcExtra

@typing_extensions.final
class ArcsPlayer(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PlayerInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AID_FIELD_NUMBER: builtins.int
    PLAYER_INFO_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    @property
    def player_info(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        player_info: collections.abc.Mapping[builtins.int, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "player_info", b"player_info"]) -> None: ...

global___ArcsPlayer = ArcsPlayer

@typing_extensions.final
class Asset(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAID_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    PREVIEW_MSG_FIELD_NUMBER: builtins.int
    paid: builtins.int
    """"""
    price: builtins.int
    """"""
    @property
    def msg(self) -> global___AssetMsg:
        """"""
    @property
    def preview_msg(self) -> global___AssetMsg:
        """"""
    def __init__(
        self,
        *,
        paid: builtins.int = ...,
        price: builtins.int = ...,
        msg: global___AssetMsg | None = ...,
        preview_msg: global___AssetMsg | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["msg", b"msg", "preview_msg", b"preview_msg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg", b"msg", "paid", b"paid", "preview_msg", b"preview_msg", "price", b"price"]) -> None: ...

global___Asset = Asset

@typing_extensions.final
class AssetMsg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESC1_FIELD_NUMBER: builtins.int
    DESC2_FIELD_NUMBER: builtins.int
    desc1: builtins.str
    """"""
    desc2: builtins.str
    """"""
    def __init__(
        self,
        *,
        desc1: builtins.str = ...,
        desc2: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc1", b"desc1", "desc2", b"desc2"]) -> None: ...

global___AssetMsg = AssetMsg

@typing_extensions.final
class Attention(google.protobuf.message.Message):
    """关注按钮卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    POS_X_FIELD_NUMBER: builtins.int
    POS_Y_FIELD_NUMBER: builtins.int
    start_time: builtins.int
    """开始时间"""
    end_time: builtins.int
    """结束时间"""
    pos_x: builtins.float
    """位置x坐标"""
    pos_y: builtins.float
    """位置y坐标"""
    def __init__(
        self,
        *,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        pos_x: builtins.float = ...,
        pos_y: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "pos_x", b"pos_x", "pos_y", b"pos_y", "start_time", b"start_time"]) -> None: ...

global___Attention = Attention

@typing_extensions.final
class Audio(google.protobuf.message.Message):
    """音频稿件信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_URL_FIELD_NUMBER: builtins.int
    SONG_ID_FIELD_NUMBER: builtins.int
    PLAY_COUNT_FIELD_NUMBER: builtins.int
    REPLY_COUNT_FIELD_NUMBER: builtins.int
    UPPER_ID_FIELD_NUMBER: builtins.int
    ENTRANCE_FIELD_NUMBER: builtins.int
    SONG_ATTR_FIELD_NUMBER: builtins.int
    title: builtins.str
    """音频标题"""
    cover_url: builtins.str
    """音频封面url"""
    song_id: builtins.int
    """音频auid"""
    play_count: builtins.int
    """音频播放量"""
    reply_count: builtins.int
    """音频评论数"""
    upper_id: builtins.int
    """音频作者UID"""
    entrance: builtins.str
    """进入按钮文案"""
    song_attr: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover_url: builtins.str = ...,
        song_id: builtins.int = ...,
        play_count: builtins.int = ...,
        reply_count: builtins.int = ...,
        upper_id: builtins.int = ...,
        entrance: builtins.str = ...,
        song_attr: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover_url", b"cover_url", "entrance", b"entrance", "play_count", b"play_count", "reply_count", b"reply_count", "song_attr", b"song_attr", "song_id", b"song_id", "title", b"title", "upper_id", b"upper_id"]) -> None: ...

global___Audio = Audio

@typing_extensions.final
class BadgeStyle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_color_night: builtins.str
    """"""
    border_color: builtins.str
    """"""
    border_color_night: builtins.str
    """"""
    bg_style: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color: builtins.str = ...,
        border_color_night: builtins.str = ...,
        bg_style: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___BadgeStyle = BadgeStyle

@typing_extensions.final
class Bgm(google.protobuf.message.Message):
    """视频引用的bgm音频"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    JUMPURL_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    sid: builtins.int
    """音频auid"""
    mid: builtins.int
    """音频作者mid"""
    title: builtins.str
    """音频标题"""
    author: builtins.str
    """音频作者昵称"""
    jumpUrl: builtins.str
    """bgm页面url"""
    cover: builtins.str
    """音频封面url"""
    def __init__(
        self,
        *,
        sid: builtins.int = ...,
        mid: builtins.int = ...,
        title: builtins.str = ...,
        author: builtins.str = ...,
        jumpUrl: builtins.str = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "cover", b"cover", "jumpUrl", b"jumpUrl", "mid", b"mid", "sid", b"sid", "title", b"title"]) -> None: ...

global___Bgm = Bgm

@typing_extensions.final
class BizFavSeasonParam(google.protobuf.message.Message):
    """收藏合集参数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """合集id"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id", b"season_id"]) -> None: ...

global___BizFavSeasonParam = BizFavSeasonParam

@typing_extensions.final
class BizFollowVideoParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id", b"season_id"]) -> None: ...

global___BizFollowVideoParam = BizFollowVideoParam

@typing_extensions.final
class BizJumpLinkParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """链接"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___BizJumpLinkParam = BizJumpLinkParam

@typing_extensions.final
class BizReserveActivityParam(google.protobuf.message.Message):
    """预约活动参数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    RESERVE_ID_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """活动id"""
    type: builtins.str
    """类型"""
    oid: builtins.int
    """资源id"""
    reserve_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        activity_id: builtins.int = ...,
        type: builtins.str = ...,
        oid: builtins.int = ...,
        reserve_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "from", b"from", "oid", b"oid", "reserve_id", b"reserve_id", "type", b"type"]) -> None: ...

global___BizReserveActivityParam = BizReserveActivityParam

@typing_extensions.final
class BizReserveGameParam(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAME_ID_FIELD_NUMBER: builtins.int
    game_id: builtins.int
    """游戏id"""
    def __init__(
        self,
        *,
        game_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["game_id", b"game_id"]) -> None: ...

global___BizReserveGameParam = BizReserveGameParam

@typing_extensions.final
class Button(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: builtins.str
    """按钮文案"""
    uri: builtins.str
    """跳转uri"""
    icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title", "uri", b"uri"]) -> None: ...

global___Button = Button

@typing_extensions.final
class ButtonStyle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    JUMP_LINK_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_color_night: builtins.str
    """"""
    jump_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        jump_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "jump_link", b"jump_link", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___ButtonStyle = ButtonStyle

@typing_extensions.final
class BuzzwordConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    FOLLOW_CONTROL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    BUZZWORD_ID_FIELD_NUMBER: builtins.int
    SCHEMA_TYPE_FIELD_NUMBER: builtins.int
    PICTURE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    schema: builtins.str
    """"""
    source: builtins.int
    """"""
    start: builtins.int
    """"""
    end: builtins.int
    """"""
    follow_control: builtins.bool
    """"""
    id: builtins.int
    """"""
    buzzword_id: builtins.int
    """"""
    schema_type: builtins.int
    """"""
    picture: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        schema: builtins.str = ...,
        source: builtins.int = ...,
        start: builtins.int = ...,
        end: builtins.int = ...,
        follow_control: builtins.bool = ...,
        id: builtins.int = ...,
        buzzword_id: builtins.int = ...,
        schema_type: builtins.int = ...,
        picture: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buzzword_id", b"buzzword_id", "end", b"end", "follow_control", b"follow_control", "id", b"id", "name", b"name", "picture", b"picture", "schema", b"schema", "schema_type", b"schema_type", "source", b"source", "start", b"start"]) -> None: ...

global___BuzzwordConfig = BuzzwordConfig

@typing_extensions.final
class CacheViewReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARC_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    OWNER_EXT_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    SEASON_FIELD_NUMBER: builtins.int
    ELEC_RANK_FIELD_NUMBER: builtins.int
    HISTORY_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    PLAYER_ICON_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    TF_PANEL_CUSTOMIZED_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Arc:
        """"""
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ViewPage]:
        """"""
    @property
    def owner_ext(self) -> global___OnwerExt:
        """"""
    @property
    def req_user(self) -> global___ReqUser:
        """"""
    @property
    def season(self) -> global___Season:
        """"""
    @property
    def elec_rank(self) -> global___ElecRank:
        """"""
    @property
    def history(self) -> global___History:
        """"""
    @property
    def dislike(self) -> global___Dislike:
        """"""
    @property
    def player_icon(self) -> global___PlayerIcon:
        """"""
    bvid: builtins.str
    """"""
    short_link: builtins.str
    """"""
    share_subtitle: builtins.str
    """"""
    @property
    def tf_panel_customized(self) -> global___TFPanelCustomized:
        """"""
    @property
    def online(self) -> global___Online:
        """"""
    def __init__(
        self,
        *,
        arc: bilibili.app.archive.v1.archive_pb2.Arc | None = ...,
        pages: collections.abc.Iterable[global___ViewPage] | None = ...,
        owner_ext: global___OnwerExt | None = ...,
        req_user: global___ReqUser | None = ...,
        season: global___Season | None = ...,
        elec_rank: global___ElecRank | None = ...,
        history: global___History | None = ...,
        dislike: global___Dislike | None = ...,
        player_icon: global___PlayerIcon | None = ...,
        bvid: builtins.str = ...,
        short_link: builtins.str = ...,
        share_subtitle: builtins.str = ...,
        tf_panel_customized: global___TFPanelCustomized | None = ...,
        online: global___Online | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc", b"arc", "dislike", b"dislike", "elec_rank", b"elec_rank", "history", b"history", "online", b"online", "owner_ext", b"owner_ext", "player_icon", b"player_icon", "req_user", b"req_user", "season", b"season", "tf_panel_customized", b"tf_panel_customized"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc", b"arc", "bvid", b"bvid", "dislike", b"dislike", "elec_rank", b"elec_rank", "history", b"history", "online", b"online", "owner_ext", b"owner_ext", "pages", b"pages", "player_icon", b"player_icon", "req_user", b"req_user", "season", b"season", "share_subtitle", b"share_subtitle", "short_link", b"short_link", "tf_panel_customized", b"tf_panel_customized"]) -> None: ...

global___CacheViewReply = CacheViewReply

@typing_extensions.final
class CacheViewReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    AD_EXTRA_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    trackid: builtins.str
    """"""
    ad_extra: builtins.str
    """"""
    spmid: builtins.str
    """"""
    from_spmid: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        trackid: builtins.str = ...,
        ad_extra: builtins.str = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra", b"ad_extra", "aid", b"aid", "bvid", b"bvid", "from", b"from", "from_spmid", b"from_spmid", "spmid", b"spmid", "trackid", b"trackid"]) -> None: ...

global___CacheViewReq = CacheViewReq

@typing_extensions.final
class Chronos(google.protobuf.message.Message):
    """Chronos灰度管理"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MD5_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    md5: builtins.str
    """资源包md5"""
    file: builtins.str
    """资源包"""
    sign: builtins.str
    """"""
    def __init__(
        self,
        *,
        md5: builtins.str = ...,
        file: builtins.str = ...,
        sign: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file", "md5", b"md5", "sign", b"sign"]) -> None: ...

global___Chronos = Chronos

@typing_extensions.final
class ChronosPkgReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_KEY_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    MESSAGE_PROTOCOL_FIELD_NUMBER: builtins.int
    service_key: builtins.str
    """"""
    engine_version: builtins.str
    """"""
    message_protocol: builtins.str
    """"""
    def __init__(
        self,
        *,
        service_key: builtins.str = ...,
        engine_version: builtins.str = ...,
        message_protocol: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["engine_version", b"engine_version", "message_protocol", b"message_protocol", "service_key", b"service_key"]) -> None: ...

global___ChronosPkgReq = ChronosPkgReq

@typing_extensions.final
class ClickActivitySeasonReq(google.protobuf.message.Message):
    """点击大型活动页预约-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDER_TYPE_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    FAV_SEASON_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    order_type: global___BizType.ValueType
    """预约类型"""
    spmid: builtins.str
    """当前页面spm"""
    @property
    def reserve(self) -> global___BizReserveActivityParam:
        """预约活动参数"""
    @property
    def fav_season(self) -> global___BizFavSeasonParam:
        """收藏合集参数"""
    action: builtins.int
    """操作
    0:操作 1:取消操作
    """
    def __init__(
        self,
        *,
        order_type: global___BizType.ValueType = ...,
        spmid: builtins.str = ...,
        reserve: global___BizReserveActivityParam | None = ...,
        fav_season: global___BizFavSeasonParam | None = ...,
        action: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav_season", b"fav_season", "order_param", b"order_param", "reserve", b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "fav_season", b"fav_season", "order_param", b"order_param", "order_type", b"order_type", "reserve", b"reserve", "spmid", b"spmid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["order_param", b"order_param"]) -> typing_extensions.Literal["reserve", "fav_season"] | None: ...

global___ClickActivitySeasonReq = ClickActivitySeasonReq

@typing_extensions.final
class ClickPlayerCardReply(google.protobuf.message.Message):
    """点击播放器卡片-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___ClickPlayerCardReply = ClickPlayerCardReply

@typing_extensions.final
class ClickPlayerCardReq(google.protobuf.message.Message):
    """点击播放器卡片-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    id: builtins.int
    """卡片id"""
    aid: builtins.int
    """稿件avid"""
    cid: builtins.int
    """视频cid"""
    action: builtins.int
    """操作
    0:操作 1:取消操作
    """
    spmid: builtins.str
    """当前页面spm"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        action: builtins.int = ...,
        spmid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "aid", b"aid", "cid", b"cid", "id", b"id", "spmid", b"spmid"]) -> None: ...

global___ClickPlayerCardReq = ClickPlayerCardReq

@typing_extensions.final
class CM(google.protobuf.message.Message):
    """广告"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_CONTENT_FIELD_NUMBER: builtins.int
    @property
    def source_content(self) -> google.protobuf.any_pb2.Any:
        """广告数据(需解包)"""
    def __init__(
        self,
        *,
        source_content: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_content", b"source_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_content", b"source_content"]) -> None: ...

global___CM = CM

@typing_extensions.final
class CMConfig(google.protobuf.message.Message):
    """广告配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADS_CONTROL_FIELD_NUMBER: builtins.int
    @property
    def ads_control(self) -> google.protobuf.any_pb2.Any:
        """广告配置数据(需要二次解包)"""
    def __init__(
        self,
        *,
        ads_control: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ads_control", b"ads_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ads_control", b"ads_control"]) -> None: ...

global___CMConfig = CMConfig

@typing_extensions.final
class CmIpad(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CM_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    @property
    def cm(self) -> global___CM:
        """"""
    @property
    def author(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Author:
        """"""
    @property
    def stat(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Stat:
        """"""
    duration: builtins.int
    """"""
    aid: builtins.int
    """"""
    def __init__(
        self,
        *,
        cm: global___CM | None = ...,
        author: bilibili.app.archive.v1.archive_pb2.Author | None = ...,
        stat: bilibili.app.archive.v1.archive_pb2.Stat | None = ...,
        duration: builtins.int = ...,
        aid: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "cm", b"cm", "stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "author", b"author", "cm", b"cm", "duration", b"duration", "stat", b"stat"]) -> None: ...

global___CmIpad = CmIpad

@typing_extensions.final
class CoinCustom(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOAST_FIELD_NUMBER: builtins.int
    toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["toast", b"toast"]) -> None: ...

global___CoinCustom = CoinCustom

@typing_extensions.final
class CommandDm(google.protobuf.message.Message):
    """互动弹幕条目信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕id"""
    oid: builtins.int
    """对象视频cid"""
    mid: builtins.int
    """发送者mid"""
    command: builtins.str
    """互动弹幕指令"""
    content: builtins.str
    """互动弹幕正文"""
    progress: builtins.int
    """出现时间"""
    ctime: builtins.str
    """创建时间"""
    mtime: builtins.str
    """发布时间"""
    extra: builtins.str
    """扩展json数据"""
    id_str: builtins.str
    """弹幕id str类型"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: builtins.int = ...,
        command: builtins.str = ...,
        content: builtins.str = ...,
        progress: builtins.int = ...,
        ctime: builtins.str = ...,
        mtime: builtins.str = ...,
        extra: builtins.str = ...,
        id_str: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "content", b"content", "ctime", b"ctime", "extra", b"extra", "id", b"id", "id_str", b"id_str", "mid", b"mid", "mtime", b"mtime", "oid", b"oid", "progress", b"progress"]) -> None: ...

global___CommandDm = CommandDm

@typing_extensions.final
class Config(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATES_TITLE_FIELD_NUMBER: builtins.int
    RELATES_STYLE_FIELD_NUMBER: builtins.int
    RELATE_GIF_EXP_FIELD_NUMBER: builtins.int
    END_PAGE_HALF_FIELD_NUMBER: builtins.int
    END_PAGE_FULL_FIELD_NUMBER: builtins.int
    AUTO_SWINDOW_FIELD_NUMBER: builtins.int
    POPUP_INFO_FIELD_NUMBER: builtins.int
    ABTEST_SMALL_WINDOW_FIELD_NUMBER: builtins.int
    REC_THREE_POINT_STYLE_FIELD_NUMBER: builtins.int
    IS_ABSOLUTE_TIME_FIELD_NUMBER: builtins.int
    NEW_SWINDOW_FIELD_NUMBER: builtins.int
    RELATES_BISERIAL_FIELD_NUMBER: builtins.int
    LISTENER_CONF_FIELD_NUMBER: builtins.int
    RELATES_FEED_STYLE_FIELD_NUMBER: builtins.int
    RELATES_FEED_POPUP_FIELD_NUMBER: builtins.int
    RELATES_HAS_NEXT_FIELD_NUMBER: builtins.int
    LOCAL_PLAY_FIELD_NUMBER: builtins.int
    PLAY_STORY_FIELD_NUMBER: builtins.int
    ARC_PLAY_STORY_FIELD_NUMBER: builtins.int
    STORY_ICON_FIELD_NUMBER: builtins.int
    LANDSCAPE_STORY_FIELD_NUMBER: builtins.int
    ARC_LANDSCAPE_STORY_FIELD_NUMBER: builtins.int
    LANDSCAPE_ICON_FIELD_NUMBER: builtins.int
    SHOW_LISTEN_BUTTON_FIELD_NUMBER: builtins.int
    relates_title: builtins.str
    """下方推荐项标题"""
    relates_style: builtins.int
    """"""
    relate_gif_exp: builtins.int
    """"""
    end_page_half: builtins.int
    """"""
    end_page_full: builtins.int
    """"""
    auto_swindow: builtins.bool
    """退出是否自动小窗"""
    popup_info: builtins.bool
    """"""
    abtest_small_window: builtins.str
    """"""
    rec_three_point_style: builtins.int
    """"""
    is_absolute_time: builtins.bool
    """"""
    new_swindow: builtins.bool
    """"""
    relates_biserial: builtins.bool
    """"""
    @property
    def listener_conf(self) -> global___ListenerConfig:
        """"""
    relates_feed_style: builtins.str
    """"""
    relates_feed_popup: builtins.bool
    """"""
    relates_has_next: builtins.bool
    """"""
    local_play: builtins.int
    """"""
    play_story: builtins.bool
    """"""
    arc_play_story: builtins.bool
    """"""
    story_icon: builtins.str
    """"""
    landscape_story: builtins.bool
    """"""
    arc_landscape_story: builtins.bool
    """"""
    landscape_icon: builtins.str
    """"""
    show_listen_button: builtins.bool
    """"""
    def __init__(
        self,
        *,
        relates_title: builtins.str = ...,
        relates_style: builtins.int = ...,
        relate_gif_exp: builtins.int = ...,
        end_page_half: builtins.int = ...,
        end_page_full: builtins.int = ...,
        auto_swindow: builtins.bool = ...,
        popup_info: builtins.bool = ...,
        abtest_small_window: builtins.str = ...,
        rec_three_point_style: builtins.int = ...,
        is_absolute_time: builtins.bool = ...,
        new_swindow: builtins.bool = ...,
        relates_biserial: builtins.bool = ...,
        listener_conf: global___ListenerConfig | None = ...,
        relates_feed_style: builtins.str = ...,
        relates_feed_popup: builtins.bool = ...,
        relates_has_next: builtins.bool = ...,
        local_play: builtins.int = ...,
        play_story: builtins.bool = ...,
        arc_play_story: builtins.bool = ...,
        story_icon: builtins.str = ...,
        landscape_story: builtins.bool = ...,
        arc_landscape_story: builtins.bool = ...,
        landscape_icon: builtins.str = ...,
        show_listen_button: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["listener_conf", b"listener_conf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["abtest_small_window", b"abtest_small_window", "arc_landscape_story", b"arc_landscape_story", "arc_play_story", b"arc_play_story", "auto_swindow", b"auto_swindow", "end_page_full", b"end_page_full", "end_page_half", b"end_page_half", "is_absolute_time", b"is_absolute_time", "landscape_icon", b"landscape_icon", "landscape_story", b"landscape_story", "listener_conf", b"listener_conf", "local_play", b"local_play", "new_swindow", b"new_swindow", "play_story", b"play_story", "popup_info", b"popup_info", "rec_three_point_style", b"rec_three_point_style", "relate_gif_exp", b"relate_gif_exp", "relates_biserial", b"relates_biserial", "relates_feed_popup", b"relates_feed_popup", "relates_feed_style", b"relates_feed_style", "relates_has_next", b"relates_has_next", "relates_style", b"relates_style", "relates_title", b"relates_title", "show_listen_button", b"show_listen_button", "story_icon", b"story_icon"]) -> None: ...

global___Config = Config

@typing_extensions.final
class ContinuousPlayReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATES_FIELD_NUMBER: builtins.int
    @property
    def relates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relate]:
        """"""
    def __init__(
        self,
        *,
        relates: collections.abc.Iterable[global___Relate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["relates", b"relates"]) -> None: ...

global___ContinuousPlayReply = ContinuousPlayReply

@typing_extensions.final
class ContinuousPlayReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    DISPLAY_ID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    trackid: builtins.str
    """"""
    spmid: builtins.str
    """"""
    from_spmid: builtins.str
    """"""
    autoplay: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    device_type: builtins.int
    """"""
    session_id: builtins.str
    """"""
    display_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        trackid: builtins.str = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        autoplay: builtins.int = ...,
        player_args: bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        device_type: builtins.int = ...,
        session_id: builtins.str = ...,
        display_id: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "autoplay", b"autoplay", "device_type", b"device_type", "display_id", b"display_id", "from", b"from", "from_spmid", b"from_spmid", "player_args", b"player_args", "session_id", b"session_id", "spmid", b"spmid", "trackid", b"trackid"]) -> None: ...

global___ContinuousPlayReq = ContinuousPlayReq

@typing_extensions.final
class ContractCard(google.protobuf.message.Message):
    """契约卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_PROGRESS_FIELD_NUMBER: builtins.int
    DISPLAY_ACCURACY_FIELD_NUMBER: builtins.int
    DISPLAY_DURATION_FIELD_NUMBER: builtins.int
    SHOW_MODE_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    UPPER_FIELD_NUMBER: builtins.int
    IS_FOLLOW_DISPLAY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    FOLLOW_DISPLAY_END_DURATION_FIELD_NUMBER: builtins.int
    IS_PLAY_DISPLAY_FIELD_NUMBER: builtins.int
    IS_INTERACT_DISPLAY_FIELD_NUMBER: builtins.int
    PLAY_DISPLAY_SWITCH_FIELD_NUMBER: builtins.int
    display_progress: builtins.float
    """需要触发的播放进度百分比"""
    display_accuracy: builtins.int
    """触发位置的前后误差(单位ms)"""
    display_duration: builtins.int
    """展示持续时间(单位ms)"""
    show_mode: builtins.int
    """弹出模式
    0: 原有模式 1: 半屏弹出 2: 全屏、半屏均弹出
    """
    page_type: builtins.int
    """提示页面
    0: 原有页面 1: 6.23版本新页面
    """
    @property
    def upper(self) -> global___UpperInfos:
        """UP主信息"""
    is_follow_display: builtins.int
    """"""
    @property
    def text(self) -> global___ContractText:
        """"""
    follow_display_end_duration: builtins.int
    """"""
    is_play_display: builtins.int
    """"""
    is_interact_display: builtins.int
    """"""
    play_display_switch: builtins.bool
    """"""
    def __init__(
        self,
        *,
        display_progress: builtins.float = ...,
        display_accuracy: builtins.int = ...,
        display_duration: builtins.int = ...,
        show_mode: builtins.int = ...,
        page_type: builtins.int = ...,
        upper: global___UpperInfos | None = ...,
        is_follow_display: builtins.int = ...,
        text: global___ContractText | None = ...,
        follow_display_end_duration: builtins.int = ...,
        is_play_display: builtins.int = ...,
        is_interact_display: builtins.int = ...,
        play_display_switch: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text", b"text", "upper", b"upper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_accuracy", b"display_accuracy", "display_duration", b"display_duration", "display_progress", b"display_progress", "follow_display_end_duration", b"follow_display_end_duration", "is_follow_display", b"is_follow_display", "is_interact_display", b"is_interact_display", "is_play_display", b"is_play_display", "page_type", b"page_type", "play_display_switch", b"play_display_switch", "show_mode", b"show_mode", "text", b"text", "upper", b"upper"]) -> None: ...

global___ContractCard = ContractCard

@typing_extensions.final
class ContractText(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    INLINE_TITLE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    inline_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        inline_title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_title", b"inline_title", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___ContractText = ContractText

@typing_extensions.final
class CreativeContent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    IMAGE_MD5_FIELD_NUMBER: builtins.int
    LOG_URL_FIELD_NUMBER: builtins.int
    LOG_MD5_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CLICK_URL_FIELD_NUMBER: builtins.int
    SHOW_URL_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    description: builtins.str
    """"""
    button_title: builtins.str
    """"""
    video_id: builtins.int
    """"""
    username: builtins.str
    """"""
    image_url: builtins.str
    """"""
    image_md5: builtins.str
    """"""
    log_url: builtins.str
    """"""
    log_md5: builtins.str
    """"""
    url: builtins.str
    """"""
    click_url: builtins.str
    """"""
    show_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        button_title: builtins.str = ...,
        video_id: builtins.int = ...,
        username: builtins.str = ...,
        image_url: builtins.str = ...,
        image_md5: builtins.str = ...,
        log_url: builtins.str = ...,
        log_md5: builtins.str = ...,
        url: builtins.str = ...,
        click_url: builtins.str = ...,
        show_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_title", b"button_title", "click_url", b"click_url", "description", b"description", "image_md5", b"image_md5", "image_url", b"image_url", "log_md5", b"log_md5", "log_url", b"log_url", "show_url", b"show_url", "title", b"title", "url", b"url", "username", b"username", "video_id", b"video_id"]) -> None: ...

global___CreativeContent = CreativeContent

@typing_extensions.final
class CustomConfig(google.protobuf.message.Message):
    """404页信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDIRECT_URL_FIELD_NUMBER: builtins.int
    redirect_url: builtins.str
    """重定向页面url"""
    def __init__(
        self,
        *,
        redirect_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["redirect_url", b"redirect_url"]) -> None: ...

global___CustomConfig = CustomConfig

@typing_extensions.final
class DescV2(google.protobuf.message.Message):
    """特殊稿件简介"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文本内容"""
    type: global___DescType.ValueType
    """文本类型"""
    uri: builtins.str
    """点击跳转链接"""
    rid: builtins.int
    """资源ID"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        type: global___DescType.ValueType = ...,
        uri: builtins.str = ...,
        rid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rid", b"rid", "text", b"text", "type", b"type", "uri", b"uri"]) -> None: ...

global___DescV2 = DescV2

@typing_extensions.final
class Dislike(google.protobuf.message.Message):
    """不喜欢原因"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    REASONS_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    subtitle: builtins.str
    """"""
    @property
    def reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReasons]:
        """原因项列表"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        reasons: collections.abc.Iterable[global___DislikeReasons] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reasons", b"reasons", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___Dislike = Dislike

@typing_extensions.final
class DislikeReasons(google.protobuf.message.Message):
    """不喜欢原因项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    TAG_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """类型
    1:全部类型 3:TAG 4:UP主
    """
    mid: builtins.int
    """相关UP主mid"""
    rid: builtins.int
    """相关分区tid"""
    tag_id: builtins.int
    """相关TAG id"""
    name: builtins.str
    """相关名称"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        mid: builtins.int = ...,
        rid: builtins.int = ...,
        tag_id: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "mid", b"mid", "name", b"name", "rid", b"rid", "tag_id", b"tag_id"]) -> None: ...

global___DislikeReasons = DislikeReasons

@typing_extensions.final
class DM(google.protobuf.message.Message):
    """分P弹幕信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOSED_FIELD_NUMBER: builtins.int
    REAL_NAME_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    closed: builtins.bool
    """分P是否关闭弹幕
    0:正常 1:关闭
    """
    real_name: builtins.bool
    """"""
    count: builtins.int
    """分P弹幕总数"""
    def __init__(
        self,
        *,
        closed: builtins.bool = ...,
        real_name: builtins.bool = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["closed", b"closed", "count", b"count", "real_name", b"real_name"]) -> None: ...

global___DM = DM

@typing_extensions.final
class ElecRank(google.protobuf.message.Message):
    """充电排行信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ElecRankItem]:
        """充电排行列表"""
    count: builtins.int
    """充电用户数"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___ElecRankItem] | None = ...,
        count: builtins.int = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "list", b"list", "text", b"text"]) -> None: ...

global___ElecRank = ElecRank

@typing_extensions.final
class ElecRankItem(google.protobuf.message.Message):
    """充电用户信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVATAR_FIELD_NUMBER: builtins.int
    NICKNAME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    avatar: builtins.str
    """用户头像url"""
    nickname: builtins.str
    """用户昵称"""
    message: builtins.str
    """充电留言"""
    mid: builtins.int
    """用户mid"""
    def __init__(
        self,
        *,
        avatar: builtins.str = ...,
        nickname: builtins.str = ...,
        message: builtins.str = ...,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "message", b"message", "mid", b"mid", "nickname", b"nickname"]) -> None: ...

global___ElecRankItem = ElecRankItem

@typing_extensions.final
class Episode(google.protobuf.message.Message):
    """视频合集单话信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVERRIGHTTEXT_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    AUTHOR_DESC_FIELD_NUMBER: builtins.int
    BADGE_STYLE_FIELD_NUMBER: builtins.int
    NEED_PAY_FIELD_NUMBER: builtins.int
    EPISODE_PAY_FIELD_NUMBER: builtins.int
    FREE_WATCH_FIELD_NUMBER: builtins.int
    FIRST_FRAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """合集单话id"""
    aid: builtins.int
    """稿件avid"""
    cid: builtins.int
    """视频1P cid"""
    title: builtins.str
    """稿件标题"""
    cover: builtins.str
    """稿件封面url"""
    coverRightText: builtins.str
    """投稿时间显示文案"""
    @property
    def page(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Page:
        """视频分P信息"""
    @property
    def stat(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Stat:
        """视频状态数"""
    bvid: builtins.str
    """稿件bvid"""
    @property
    def author(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Author:
        """稿件UP主信息"""
    author_desc: builtins.str
    """"""
    @property
    def badge_style(self) -> global___BadgeStyle:
        """"""
    need_pay: builtins.bool
    """"""
    episode_pay: builtins.bool
    """"""
    free_watch: builtins.bool
    """"""
    first_frame: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        coverRightText: builtins.str = ...,
        page: bilibili.app.archive.v1.archive_pb2.Page | None = ...,
        stat: bilibili.app.archive.v1.archive_pb2.Stat | None = ...,
        bvid: builtins.str = ...,
        author: bilibili.app.archive.v1.archive_pb2.Author | None = ...,
        author_desc: builtins.str = ...,
        badge_style: global___BadgeStyle | None = ...,
        need_pay: builtins.bool = ...,
        episode_pay: builtins.bool = ...,
        free_watch: builtins.bool = ...,
        first_frame: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "badge_style", b"badge_style", "page", b"page", "stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "author", b"author", "author_desc", b"author_desc", "badge_style", b"badge_style", "bvid", b"bvid", "cid", b"cid", "cover", b"cover", "coverRightText", b"coverRightText", "episode_pay", b"episode_pay", "first_frame", b"first_frame", "free_watch", b"free_watch", "id", b"id", "need_pay", b"need_pay", "page", b"page", "stat", b"stat", "title", b"title"]) -> None: ...

global___Episode = Episode

@typing_extensions.final
class ExposePlayerCardReq(google.protobuf.message.Message):
    """播放器卡片曝光-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CARD_TYPE_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    card_type: global___PlayerCardType.ValueType
    """卡片类型"""
    aid: builtins.int
    """稿件avid"""
    cid: builtins.int
    """视频cid"""
    spmid: builtins.str
    """当前页面spm"""
    def __init__(
        self,
        *,
        card_type: global___PlayerCardType.ValueType = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        spmid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "card_type", b"card_type", "cid", b"cid", "spmid", b"spmid"]) -> None: ...

global___ExposePlayerCardReq = ExposePlayerCardReq

@typing_extensions.final
class FeedViewItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIEW_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    @property
    def view(self) -> global___ViewReply:
        """"""
    goto: builtins.str
    """"""
    uri: builtins.str
    """"""
    track_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        view: global___ViewReply | None = ...,
        goto: builtins.str = ...,
        uri: builtins.str = ...,
        track_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["goto", b"goto", "track_id", b"track_id", "uri", b"uri", "view", b"view"]) -> None: ...

global___FeedViewItem = FeedViewItem

@typing_extensions.final
class FeedViewReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    HAS_NEXT_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeedViewItem]:
        """"""
    has_next: builtins.bool
    """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___FeedViewItem] | None = ...,
        has_next: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_next", b"has_next", "list", b"list"]) -> None: ...

global___FeedViewReply = FeedViewReply

@typing_extensions.final
class FeedViewReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    DISPLAY_ID_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    PAGE_VERSION_FIELD_NUMBER: builtins.int
    FROM_TRACK_ID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    spmid: builtins.str
    """"""
    from_spmid: builtins.str
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    display_id: builtins.int
    """"""
    session_id: builtins.str
    """"""
    page_version: builtins.str
    """"""
    from_track_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        player_args: bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        display_id: builtins.int = ...,
        session_id: builtins.str = ...,
        page_version: builtins.str = ...,
        from_track_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "bvid", b"bvid", "display_id", b"display_id", "from", b"from", "from_spmid", b"from_spmid", "from_track_id", b"from_track_id", "page_version", b"page_version", "player_args", b"player_args", "session_id", b"session_id", "spmid", b"spmid"]) -> None: ...

global___FeedViewReq = FeedViewReq

@typing_extensions.final
class GetArcsPlayerReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARCS_PLAYER_FIELD_NUMBER: builtins.int
    @property
    def arcs_player(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ArcsPlayer]:
        """"""
    def __init__(
        self,
        *,
        arcs_player: collections.abc.Iterable[global___ArcsPlayer] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arcs_player", b"arcs_player"]) -> None: ...

global___GetArcsPlayerReply = GetArcsPlayerReply

@typing_extensions.final
class GetArcsPlayerReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAY_AVS_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    @property
    def play_avs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayAv]:
        """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    def __init__(
        self,
        *,
        play_avs: collections.abc.Iterable[global___PlayAv] | None = ...,
        player_args: bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_avs", b"play_avs", "player_args", b"player_args"]) -> None: ...

global___GetArcsPlayerReq = GetArcsPlayerReq

@typing_extensions.final
class GoodsInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GOODS_ID_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    GOODS_PRICE_FIELD_NUMBER: builtins.int
    PAY_STATE_FIELD_NUMBER: builtins.int
    GOODS_NAME_FIELD_NUMBER: builtins.int
    PRICE_FMT_FIELD_NUMBER: builtins.int
    goods_id: builtins.str
    """"""
    category: builtins.int
    """"""
    goods_price: builtins.int
    """"""
    pay_state: global___PayState.ValueType
    """"""
    goods_name: builtins.str
    """"""
    price_fmt: builtins.str
    """"""
    def __init__(
        self,
        *,
        goods_id: builtins.str = ...,
        category: builtins.int = ...,
        goods_price: builtins.int = ...,
        pay_state: global___PayState.ValueType = ...,
        goods_name: builtins.str = ...,
        price_fmt: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["category", b"category", "goods_id", b"goods_id", "goods_name", b"goods_name", "goods_price", b"goods_price", "pay_state", b"pay_state", "price_fmt", b"price_fmt"]) -> None: ...

global___GoodsInfo = GoodsInfo

@typing_extensions.final
class History(google.protobuf.message.Message):
    """稿件观看进度"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """播放进度分P cid"""
    progress: builtins.int
    """播放进度时间
    0:未观看 -1:已看完 正整数:播放时间进度
    """
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
        progress: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "progress", b"progress"]) -> None: ...

global___History = History

@typing_extensions.final
class Honor(google.protobuf.message.Message):
    """稿件获得荣誉信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    ICON_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_EXTRA_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    URL_TEXT_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """荣誉栏图标url"""
    icon_night: builtins.str
    """荣誉栏图标url 夜间模式"""
    text: builtins.str
    """荣誉文案"""
    text_extra: builtins.str
    """荣誉副文案"""
    text_color: builtins.str
    """标题颜色"""
    text_color_night: builtins.str
    """标题颜色 夜间模式"""
    bg_color: builtins.str
    """背景颜色"""
    bg_color_night: builtins.str
    """背景颜色 夜间模式"""
    url: builtins.str
    """跳转uri"""
    url_text: builtins.str
    """跳转角标文案"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        icon_night: builtins.str = ...,
        text: builtins.str = ...,
        text_extra: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        url: builtins.str = ...,
        url_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "icon", b"icon", "icon_night", b"icon_night", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night", "text_extra", b"text_extra", "url", b"url", "url_text", b"url_text"]) -> None: ...

global___Honor = Honor

@typing_extensions.final
class IconData(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_JSON_FIELD_NUMBER: builtins.int
    SPRITS_IMG_FIELD_NUMBER: builtins.int
    meta_json: builtins.str
    """"""
    sprits_img: builtins.str
    """"""
    def __init__(
        self,
        *,
        meta_json: builtins.str = ...,
        sprits_img: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["meta_json", b"meta_json", "sprits_img", b"sprits_img"]) -> None: ...

global___IconData = IconData

@typing_extensions.final
class Interaction(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HISTORY_NODE_FIELD_NUMBER: builtins.int
    GRAPH_VERSION_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    EVALUATION_FIELD_NUMBER: builtins.int
    MARK_FIELD_NUMBER: builtins.int
    @property
    def history_node(self) -> global___Node:
        """"""
    graph_version: builtins.int
    """"""
    msg: builtins.str
    """"""
    evaluation: builtins.str
    """"""
    mark: builtins.int
    """"""
    def __init__(
        self,
        *,
        history_node: global___Node | None = ...,
        graph_version: builtins.int = ...,
        msg: builtins.str = ...,
        evaluation: builtins.str = ...,
        mark: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["history_node", b"history_node"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["evaluation", b"evaluation", "graph_version", b"graph_version", "history_node", b"history_node", "mark", b"mark", "msg", b"msg"]) -> None: ...

global___Interaction = Interaction

@typing_extensions.final
class Label(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    ICON_NIGHT_FIELD_NUMBER: builtins.int
    ICON_WIDTH_FIELD_NUMBER: builtins.int
    ICON_HEIGHT_FIELD_NUMBER: builtins.int
    LOTTIE_FIELD_NUMBER: builtins.int
    LOTTIE_NIGHT_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    uri: builtins.str
    """"""
    icon: builtins.str
    """"""
    icon_night: builtins.str
    """"""
    icon_width: builtins.int
    """"""
    icon_height: builtins.int
    """"""
    lottie: builtins.str
    """"""
    lottie_night: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        uri: builtins.str = ...,
        icon: builtins.str = ...,
        icon_night: builtins.str = ...,
        icon_width: builtins.int = ...,
        icon_height: builtins.int = ...,
        lottie: builtins.str = ...,
        lottie_night: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "icon_height", b"icon_height", "icon_night", b"icon_night", "icon_width", b"icon_width", "lottie", b"lottie", "lottie_night", b"lottie_night", "type", b"type", "uri", b"uri"]) -> None: ...

global___Label = Label

@typing_extensions.final
class LikeAnimation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIKE_ICON_FIELD_NUMBER: builtins.int
    LIKED_ICON_FIELD_NUMBER: builtins.int
    LIKE_ANIMATION_FIELD_NUMBER: builtins.int
    like_icon: builtins.str
    """"""
    liked_icon: builtins.str
    """"""
    like_animation: builtins.str
    """"""
    def __init__(
        self,
        *,
        like_icon: builtins.str = ...,
        liked_icon: builtins.str = ...,
        like_animation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["like_animation", b"like_animation", "like_icon", b"like_icon", "liked_icon", b"liked_icon"]) -> None: ...

global___LikeAnimation = LikeAnimation

@typing_extensions.final
class LikeCustom(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIKE_SWITCH_FIELD_NUMBER: builtins.int
    FULL_TO_HALF_PROGRESS_FIELD_NUMBER: builtins.int
    NON_FULL_PROGRESS_FIELD_NUMBER: builtins.int
    UPDATE_COUNT_FIELD_NUMBER: builtins.int
    like_switch: builtins.bool
    """"""
    full_to_half_progress: builtins.int
    """"""
    non_full_progress: builtins.int
    """"""
    update_count: builtins.int
    """"""
    def __init__(
        self,
        *,
        like_switch: builtins.bool = ...,
        full_to_half_progress: builtins.int = ...,
        non_full_progress: builtins.int = ...,
        update_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["full_to_half_progress", b"full_to_half_progress", "like_switch", b"like_switch", "non_full_progress", b"non_full_progress", "update_count", b"update_count"]) -> None: ...

global___LikeCustom = LikeCustom

@typing_extensions.final
class ListenerConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JUMP_STYLE_FIELD_NUMBER: builtins.int
    GUIDE_BAR_FIELD_NUMBER: builtins.int
    jump_style: builtins.int
    """"""
    @property
    def guide_bar(self) -> global___ListenerGuideBar:
        """"""
    def __init__(
        self,
        *,
        jump_style: builtins.int = ...,
        guide_bar: global___ListenerGuideBar | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["guide_bar", b"guide_bar"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["guide_bar", b"guide_bar", "jump_style", b"jump_style"]) -> None: ...

global___ListenerConfig = ListenerConfig

@typing_extensions.final
class ListenerGuideBar(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_STRATEGY_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    BTN_TEXT_FIELD_NUMBER: builtins.int
    SHOW_TIME_FIELD_NUMBER: builtins.int
    BACKGROUND_TIME_FIELD_NUMBER: builtins.int
    show_strategy: builtins.int
    """"""
    icon: builtins.str
    """"""
    text: builtins.str
    """"""
    btn_text: builtins.str
    """"""
    show_time: builtins.int
    """"""
    background_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        show_strategy: builtins.int = ...,
        icon: builtins.str = ...,
        text: builtins.str = ...,
        btn_text: builtins.str = ...,
        show_time: builtins.int = ...,
        background_time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_time", b"background_time", "btn_text", b"btn_text", "icon", b"icon", "show_strategy", b"show_strategy", "show_time", b"show_time", "text", b"text"]) -> None: ...

global___ListenerGuideBar = ListenerGuideBar

@typing_extensions.final
class Live(google.protobuf.message.Message):
    """直播信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    ROOMID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ENDPAGE_URI_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """主播UID"""
    roomid: builtins.int
    """直播间id"""
    uri: builtins.str
    """直播间url"""
    endpage_uri: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        roomid: builtins.int = ...,
        uri: builtins.str = ...,
        endpage_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpage_uri", b"endpage_uri", "mid", b"mid", "roomid", b"roomid", "uri", b"uri"]) -> None: ...

global___Live = Live

@typing_extensions.final
class LiveOrderInfo(google.protobuf.message.Message):
    """直播预约信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LIVE_PLAN_START_TIME_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    sid: builtins.int
    """预约id"""
    text: builtins.str
    """预约条文案"""
    live_plan_start_time: builtins.int
    """直播开始时间"""
    is_follow: builtins.bool
    """是否预约"""
    def __init__(
        self,
        *,
        sid: builtins.int = ...,
        text: builtins.str = ...,
        live_plan_start_time: builtins.int = ...,
        is_follow: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow", b"is_follow", "live_plan_start_time", b"live_plan_start_time", "sid", b"sid", "text", b"text"]) -> None: ...

global___LiveOrderInfo = LiveOrderInfo

@typing_extensions.final
class MaterialLeft(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    LEFT_TYPE_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    OPERATIONAL_TYPE_FIELD_NUMBER: builtins.int
    STATIC_ICON_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """"""
    text: builtins.str
    """"""
    url: builtins.str
    """"""
    left_type: builtins.str
    """"""
    param: builtins.str
    """"""
    operational_type: builtins.str
    """"""
    static_icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        text: builtins.str = ...,
        url: builtins.str = ...,
        left_type: builtins.str = ...,
        param: builtins.str = ...,
        operational_type: builtins.str = ...,
        static_icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "left_type", b"left_type", "operational_type", b"operational_type", "param", b"param", "static_icon", b"static_icon", "text", b"text", "url", b"url"]) -> None: ...

global___MaterialLeft = MaterialLeft

@typing_extensions.final
class MaterialRes(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_PIC_FIELD_NUMBER: builtins.int
    JUMP_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    icon: builtins.str
    """"""
    url: builtins.str
    """"""
    type: global___MaterialSource.ValueType
    """"""
    name: builtins.str
    """"""
    bg_color: builtins.str
    """"""
    bg_pic: builtins.str
    """"""
    jump_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        icon: builtins.str = ...,
        url: builtins.str = ...,
        type: global___MaterialSource.ValueType = ...,
        name: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_pic: builtins.str = ...,
        jump_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_pic", b"bg_pic", "icon", b"icon", "id", b"id", "jump_type", b"jump_type", "name", b"name", "type", b"type", "url", b"url"]) -> None: ...

global___MaterialRes = MaterialRes

@typing_extensions.final
class Node(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    node_id: builtins.int
    """"""
    title: builtins.str
    """"""
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        node_id: builtins.int = ...,
        title: builtins.str = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "node_id", b"node_id", "title", b"title"]) -> None: ...

global___Node = Node

@typing_extensions.final
class NoReply(google.protobuf.message.Message):
    """空回复"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReply = NoReply

@typing_extensions.final
class Notice(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    desc: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "title", b"title"]) -> None: ...

global___Notice = Notice

@typing_extensions.final
class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """认证类型
    0:个人认证 1:官方认证
    """
    desc: builtins.str
    """认证名称"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "type", b"type"]) -> None: ...

global___OfficialVerify = OfficialVerify

@typing_extensions.final
class Online(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_SHOW_FIELD_NUMBER: builtins.int
    PLAYER_ONLINE_LOGO_FIELD_NUMBER: builtins.int
    online_show: builtins.bool
    """"""
    player_online_logo: builtins.str
    """"""
    def __init__(
        self,
        *,
        online_show: builtins.bool = ...,
        player_online_logo: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["online_show", b"online_show", "player_online_logo", b"player_online_logo"]) -> None: ...

global___Online = Online

@typing_extensions.final
class OnwerExt(google.protobuf.message.Message):
    """UP主扩展信息 ("OnwerExt"为源码中拼写错误)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    LIVE_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    ASSISTS_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    ARC_COUNT_FIELD_NUMBER: builtins.int
    @property
    def official_verify(self) -> global___OfficialVerify:
        """认证信息"""
    @property
    def live(self) -> global___Live:
        """直播信息"""
    @property
    def vip(self) -> global___Vip:
        """会员信息"""
    @property
    def assists(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
    fans: builtins.int
    """粉丝数"""
    arc_count: builtins.str
    """总投稿数"""
    def __init__(
        self,
        *,
        official_verify: global___OfficialVerify | None = ...,
        live: global___Live | None = ...,
        vip: global___Vip | None = ...,
        assists: collections.abc.Iterable[builtins.int] | None = ...,
        fans: builtins.int = ...,
        arc_count: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["live", b"live", "official_verify", b"official_verify", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_count", b"arc_count", "assists", b"assists", "fans", b"fans", "live", b"live", "official_verify", b"official_verify", "vip", b"vip"]) -> None: ...

global___OnwerExt = OnwerExt

@typing_extensions.final
class OperationCard(google.protobuf.message.Message):
    """老运营卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BUTTON_TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    start_time: builtins.int
    """开始时间(单位为秒)"""
    end_time: builtins.int
    """结束时间(单位为秒)"""
    icon: builtins.str
    """图标"""
    title: builtins.str
    """标题"""
    button_text: builtins.str
    """按钮文案"""
    url: builtins.str
    """跳转链接"""
    content: builtins.str
    """内容描述"""
    def __init__(
        self,
        *,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        button_text: builtins.str = ...,
        url: builtins.str = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_text", b"button_text", "content", b"content", "end_time", b"end_time", "icon", b"icon", "start_time", b"start_time", "title", b"title", "url", b"url"]) -> None: ...

global___OperationCard = OperationCard

@typing_extensions.final
class OperationCardNew(google.protobuf.message.Message):
    """内嵌操作按钮卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    STANDARD_FIELD_NUMBER: builtins.int
    SKIP_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    FOLLOW_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    JUMP_FIELD_NUMBER: builtins.int
    GAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """卡片id"""
    to: builtins.int
    """结束时间"""
    status: builtins.bool
    """用户操作态
    true已操作 false未操作
    """
    card_type: global___OperationCardType.ValueType
    """卡片类型"""
    @property
    def standard(self) -> global___StandardCard:
        """标准卡"""
    @property
    def skip(self) -> global___OperationCard:
        """老运营卡片(原B剪跳转卡)"""
    biz_type: global___BizType.ValueType
    """"""
    @property
    def follow(self) -> global___BizFollowVideoParam:
        """追番追剧参数"""
    @property
    def reserve(self) -> global___BizReserveActivityParam:
        """预约活动参数"""
    @property
    def jump(self) -> global___BizJumpLinkParam:
        """跳转参数"""
    @property
    def game(self) -> global___BizReserveGameParam:
        """预约游戏参数"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        to: builtins.int = ...,
        status: builtins.bool = ...,
        card_type: global___OperationCardType.ValueType = ...,
        standard: global___StandardCard | None = ...,
        skip: global___OperationCard | None = ...,
        biz_type: global___BizType.ValueType = ...,
        follow: global___BizFollowVideoParam | None = ...,
        reserve: global___BizReserveActivityParam | None = ...,
        jump: global___BizJumpLinkParam | None = ...,
        game: global___BizReserveGameParam | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["follow", b"follow", "game", b"game", "jump", b"jump", "param", b"param", "render", b"render", "reserve", b"reserve", "skip", b"skip", "standard", b"standard"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_type", b"biz_type", "card_type", b"card_type", "follow", b"follow", "from", b"from", "game", b"game", "id", b"id", "jump", b"jump", "param", b"param", "render", b"render", "reserve", b"reserve", "skip", b"skip", "standard", b"standard", "status", b"status", "to", b"to"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["param", b"param"]) -> typing_extensions.Literal["follow", "reserve", "jump", "game"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["render", b"render"]) -> typing_extensions.Literal["standard", "skip"] | None: ...

global___OperationCardNew = OperationCardNew

@typing_extensions.final
class OperationCardV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    BIZFOLLOWVIDEOPARAM_FIELD_NUMBER: builtins.int
    BIZRESERVEACTIVITYPARAM_FIELD_NUMBER: builtins.int
    BIZJUMPLINKPARAM_FIELD_NUMBER: builtins.int
    BIZRESERVEGAMEPARAM_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    to: builtins.int
    """"""
    status: builtins.bool
    """"""
    biz_type: builtins.int
    """"""
    @property
    def content(self) -> global___OperationCardV2Content:
        """"""
    @property
    def BizFollowVideoParam(self) -> global___BizFollowVideoParam:
        """"""
    @property
    def BizReserveActivityParam(self) -> global___BizReserveActivityParam:
        """"""
    @property
    def BizJumpLinkParam(self) -> global___BizJumpLinkParam:
        """"""
    @property
    def BizReserveGameParam(self) -> global___BizReserveGameParam:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        to: builtins.int = ...,
        status: builtins.bool = ...,
        biz_type: builtins.int = ...,
        content: global___OperationCardV2Content | None = ...,
        BizFollowVideoParam: global___BizFollowVideoParam | None = ...,
        BizReserveActivityParam: global___BizReserveActivityParam | None = ...,
        BizJumpLinkParam: global___BizJumpLinkParam | None = ...,
        BizReserveGameParam: global___BizReserveGameParam | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["BizFollowVideoParam", b"BizFollowVideoParam", "BizJumpLinkParam", b"BizJumpLinkParam", "BizReserveActivityParam", b"BizReserveActivityParam", "BizReserveGameParam", b"BizReserveGameParam", "content", b"content", "param", b"param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["BizFollowVideoParam", b"BizFollowVideoParam", "BizJumpLinkParam", b"BizJumpLinkParam", "BizReserveActivityParam", b"BizReserveActivityParam", "BizReserveGameParam", b"BizReserveGameParam", "biz_type", b"biz_type", "content", b"content", "from", b"from", "id", b"id", "param", b"param", "status", b"status", "to", b"to"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["param", b"param"]) -> typing_extensions.Literal["BizFollowVideoParam", "BizReserveActivityParam", "BizJumpLinkParam", "BizReserveGameParam"] | None: ...

global___OperationCardV2 = OperationCardV2

@typing_extensions.final
class OperationCardV2Content(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    BUTTON_SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SHOW_SELECTED_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    icon: builtins.str
    """"""
    button_title: builtins.str
    """"""
    button_selected_title: builtins.str
    """"""
    show_selected: builtins.bool
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        icon: builtins.str = ...,
        button_title: builtins.str = ...,
        button_selected_title: builtins.str = ...,
        show_selected: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_selected_title", b"button_selected_title", "button_title", b"button_title", "icon", b"icon", "show_selected", b"show_selected", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___OperationCardV2Content = OperationCardV2Content

@typing_extensions.final
class OperationRelate(google.protobuf.message.Message):
    """相关推荐(运营配置+AI推荐)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    RELATE_ITEM_FIELD_NUMBER: builtins.int
    AI_RELATE_ITEM_FIELD_NUMBER: builtins.int
    title: builtins.str
    """模块标题"""
    @property
    def relate_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RelateItem]:
        """相关推荐模块内容"""
    @property
    def ai_relate_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relate]:
        """AI相关推荐"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        relate_item: collections.abc.Iterable[global___RelateItem] | None = ...,
        ai_relate_item: collections.abc.Iterable[global___Relate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_relate_item", b"ai_relate_item", "relate_item", b"relate_item", "title", b"title"]) -> None: ...

global___OperationRelate = OperationRelate

@typing_extensions.final
class Order(google.protobuf.message.Message):
    """预约模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    BUTTON_SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SEASON_STAT_VIEW_FIELD_NUMBER: builtins.int
    SEASON_STAT_DANMAKU_FIELD_NUMBER: builtins.int
    ORDER_TYPE_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    FAV_SEASON_FIELD_NUMBER: builtins.int
    INTRO_FIELD_NUMBER: builtins.int
    status: builtins.bool
    """用户操作态"""
    title: builtins.str
    """模块标题"""
    button_title: builtins.str
    """按钮文字 未操作"""
    button_selected_title: builtins.str
    """按钮文字 已操作"""
    season_stat_view: builtins.int
    """合集播放数"""
    season_stat_danmaku: builtins.int
    """合集弹幕数"""
    order_type: global___BizType.ValueType
    """预约类型(点击时透传，直播开始前预约活动，直播开始后收藏合集)"""
    @property
    def reserve(self) -> global___BizReserveActivityParam:
        """预约活动参数"""
    @property
    def fav_season(self) -> global___BizFavSeasonParam:
        """收藏合集参数"""
    intro: builtins.str
    """合集简介"""
    def __init__(
        self,
        *,
        status: builtins.bool = ...,
        title: builtins.str = ...,
        button_title: builtins.str = ...,
        button_selected_title: builtins.str = ...,
        season_stat_view: builtins.int = ...,
        season_stat_danmaku: builtins.int = ...,
        order_type: global___BizType.ValueType = ...,
        reserve: global___BizReserveActivityParam | None = ...,
        fav_season: global___BizFavSeasonParam | None = ...,
        intro: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav_season", b"fav_season", "order_param", b"order_param", "reserve", b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_selected_title", b"button_selected_title", "button_title", b"button_title", "fav_season", b"fav_season", "intro", b"intro", "order_param", b"order_param", "order_type", b"order_type", "reserve", b"reserve", "season_stat_danmaku", b"season_stat_danmaku", "season_stat_view", b"season_stat_view", "status", b"status", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["order_param", b"order_param"]) -> typing_extensions.Literal["reserve", "fav_season"] | None: ...

global___Order = Order

@typing_extensions.final
class PackInfo(google.protobuf.message.Message):
    """游戏礼包信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: builtins.str
    """礼包标题"""
    uri: builtins.str
    """礼包页uri"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title", b"title", "uri", b"uri"]) -> None: ...

global___PackInfo = PackInfo

@typing_extensions.final
class PlayAv(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid"]) -> None: ...

global___PlayAv = PlayAv

@typing_extensions.final
class PlayerIcon(google.protobuf.message.Message):
    """进度条动画配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL1_FIELD_NUMBER: builtins.int
    HASH1_FIELD_NUMBER: builtins.int
    URL2_FIELD_NUMBER: builtins.int
    HASH2_FIELD_NUMBER: builtins.int
    DRAG_LEFT_PNG_FIELD_NUMBER: builtins.int
    MIDDLE_PNG_FIELD_NUMBER: builtins.int
    DRAG_RIGHT_PNG_FIELD_NUMBER: builtins.int
    DRAG_DATA_FIELD_NUMBER: builtins.int
    NODRAG_DATA_FIELD_NUMBER: builtins.int
    url1: builtins.str
    """拖动动画配置档url"""
    hash1: builtins.str
    """拖动动画配置档hash"""
    url2: builtins.str
    """松手动画配置档url"""
    hash2: builtins.str
    """松手动画配置档hash"""
    drag_left_png: builtins.str
    """"""
    middle_png: builtins.str
    """"""
    drag_right_png: builtins.str
    """"""
    @property
    def drag_data(self) -> global___IconData:
        """"""
    @property
    def nodrag_data(self) -> global___IconData:
        """"""
    def __init__(
        self,
        *,
        url1: builtins.str = ...,
        hash1: builtins.str = ...,
        url2: builtins.str = ...,
        hash2: builtins.str = ...,
        drag_left_png: builtins.str = ...,
        middle_png: builtins.str = ...,
        drag_right_png: builtins.str = ...,
        drag_data: global___IconData | None = ...,
        nodrag_data: global___IconData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["drag_data", b"drag_data", "nodrag_data", b"nodrag_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["drag_data", b"drag_data", "drag_left_png", b"drag_left_png", "drag_right_png", b"drag_right_png", "hash1", b"hash1", "hash2", b"hash2", "middle_png", b"middle_png", "nodrag_data", b"nodrag_data", "url1", b"url1", "url2", b"url2"]) -> None: ...

global___PlayerIcon = PlayerIcon

@typing_extensions.final
class PlayerRelatesReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relate]:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___Relate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list"]) -> None: ...

global___PlayerRelatesReply = PlayerRelatesReply

@typing_extensions.final
class PlayerRelatesReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    FROM_TRACK_ID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    spmid: builtins.str
    """"""
    from_spmid: builtins.str
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    session_id: builtins.str
    """"""
    from_track_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        player_args: bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        session_id: builtins.str = ...,
        from_track_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "bvid", b"bvid", "from", b"from", "from_spmid", b"from_spmid", "from_track_id", b"from_track_id", "player_args", b"player_args", "session_id", b"session_id", "spmid", b"spmid"]) -> None: ...

global___PlayerRelatesReq = PlayerRelatesReq

@typing_extensions.final
class PointMaterial(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    MATERIAL_SOURCE_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    material_source: builtins.int
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        material_source: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["material_source", b"material_source", "url", b"url"]) -> None: ...

global___PointMaterial = PointMaterial

@typing_extensions.final
class PowerIconStyle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_URL_FIELD_NUMBER: builtins.int
    ICON_NIGHT_URL_FIELD_NUMBER: builtins.int
    ICON_WIDTH_FIELD_NUMBER: builtins.int
    ICON_HEIGHT_FIELD_NUMBER: builtins.int
    icon_url: builtins.str
    """"""
    icon_night_url: builtins.str
    """"""
    icon_width: builtins.int
    """"""
    icon_height: builtins.int
    """"""
    def __init__(
        self,
        *,
        icon_url: builtins.str = ...,
        icon_night_url: builtins.str = ...,
        icon_width: builtins.int = ...,
        icon_height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon_height", b"icon_height", "icon_night_url", b"icon_night_url", "icon_url", b"icon_url", "icon_width", b"icon_width"]) -> None: ...

global___PowerIconStyle = PowerIconStyle

@typing_extensions.final
class Premiere(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREMIERE_STATE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    SERVICE_TIME_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    premiere_state: global___PremiereState.ValueType
    """"""
    start_time: builtins.int
    """"""
    service_time: builtins.int
    """"""
    room_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        premiere_state: global___PremiereState.ValueType = ...,
        start_time: builtins.int = ...,
        service_time: builtins.int = ...,
        room_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["premiere_state", b"premiere_state", "room_id", b"room_id", "service_time", b"service_time", "start_time", b"start_time"]) -> None: ...

global___Premiere = Premiere

@typing_extensions.final
class PremiereArchiveReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREMIERE_FIELD_NUMBER: builtins.int
    RISK_STATUS_FIELD_NUMBER: builtins.int
    RISK_REASON_FIELD_NUMBER: builtins.int
    @property
    def premiere(self) -> global___Premiere:
        """"""
    risk_status: builtins.bool
    """"""
    risk_reason: builtins.str
    """"""
    def __init__(
        self,
        *,
        premiere: global___Premiere | None = ...,
        risk_status: builtins.bool = ...,
        risk_reason: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["premiere", b"premiere"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["premiere", b"premiere", "risk_reason", b"risk_reason", "risk_status", b"risk_status"]) -> None: ...

global___PremiereArchiveReply = PremiereArchiveReply

@typing_extensions.final
class PremiereArchiveReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid"]) -> None: ...

global___PremiereArchiveReq = PremiereArchiveReq

@typing_extensions.final
class PremiereReserve(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVE_ID_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    reserve_id: builtins.int
    """"""
    count: builtins.int
    """"""
    is_follow: builtins.bool
    """"""
    def __init__(
        self,
        *,
        reserve_id: builtins.int = ...,
        count: builtins.int = ...,
        is_follow: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "is_follow", b"is_follow", "reserve_id", b"reserve_id"]) -> None: ...

global___PremiereReserve = PremiereReserve

@typing_extensions.final
class PremiereResource(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREMIERE_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    @property
    def premiere(self) -> global___Premiere:
        """"""
    @property
    def reserve(self) -> global___PremiereReserve:
        """"""
    @property
    def text(self) -> global___PremiereText:
        """"""
    def __init__(
        self,
        *,
        premiere: global___Premiere | None = ...,
        reserve: global___PremiereReserve | None = ...,
        text: global___PremiereText | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["premiere", b"premiere", "reserve", b"reserve", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["premiere", b"premiere", "reserve", b"reserve", "text", b"text"]) -> None: ...

global___PremiereResource = PremiereResource

@typing_extensions.final
class PremiereText(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    ONLINE_TEXT_FIELD_NUMBER: builtins.int
    ONLINE_ICON_FIELD_NUMBER: builtins.int
    ONLINE_ICON_DARK_FIELD_NUMBER: builtins.int
    INTRO_TITLE_FIELD_NUMBER: builtins.int
    INTRO_ICON_FIELD_NUMBER: builtins.int
    GUIDANCE_PULLDOWN_FIELD_NUMBER: builtins.int
    GUIDANCE_ENTRY_FIELD_NUMBER: builtins.int
    INTRO_ICON_NIGHT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    subtitle: builtins.str
    """"""
    online_text: builtins.str
    """"""
    online_icon: builtins.str
    """"""
    online_icon_dark: builtins.str
    """"""
    intro_title: builtins.str
    """"""
    intro_icon: builtins.str
    """"""
    guidance_pulldown: builtins.str
    """"""
    guidance_entry: builtins.str
    """"""
    intro_icon_night: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        online_text: builtins.str = ...,
        online_icon: builtins.str = ...,
        online_icon_dark: builtins.str = ...,
        intro_title: builtins.str = ...,
        intro_icon: builtins.str = ...,
        guidance_pulldown: builtins.str = ...,
        guidance_entry: builtins.str = ...,
        intro_icon_night: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["guidance_entry", b"guidance_entry", "guidance_pulldown", b"guidance_pulldown", "intro_icon", b"intro_icon", "intro_icon_night", b"intro_icon_night", "intro_title", b"intro_title", "online_icon", b"online_icon", "online_icon_dark", b"online_icon_dark", "online_text", b"online_text", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___PremiereText = PremiereText

@typing_extensions.final
class PullClientAction(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    PULL_ACTION_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    type: builtins.str
    """"""
    pull_action: builtins.bool
    """"""
    params: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        pull_action: builtins.bool = ...,
        params: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params", "pull_action", b"pull_action", "type", b"type"]) -> None: ...

global___PullClientAction = PullClientAction

@typing_extensions.final
class Rank(google.protobuf.message.Message):
    """排行榜"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    ICON_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """排行榜icon"""
    icon_night: builtins.str
    """排行榜icon 夜间模式"""
    text: builtins.str
    """排行榜文案"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        icon_night: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "icon_night", b"icon_night", "text", b"text"]) -> None: ...

global___Rank = Rank

@typing_extensions.final
class RankInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_URL_NIGHT_FIELD_NUMBER: builtins.int
    ICON_URL_DAY_FIELD_NUMBER: builtins.int
    BKG_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    BKG_DAY_COLOR_FIELD_NUMBER: builtins.int
    FONT_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    FONT_DAY_COLOR_FIELD_NUMBER: builtins.int
    RANK_CONTENT_FIELD_NUMBER: builtins.int
    RANK_LINK_FIELD_NUMBER: builtins.int
    icon_url_night: builtins.str
    """"""
    icon_url_day: builtins.str
    """"""
    bkg_night_color: builtins.str
    """"""
    bkg_day_color: builtins.str
    """"""
    font_night_color: builtins.str
    """"""
    font_day_color: builtins.str
    """"""
    rank_content: builtins.str
    """"""
    rank_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon_url_night: builtins.str = ...,
        icon_url_day: builtins.str = ...,
        bkg_night_color: builtins.str = ...,
        bkg_day_color: builtins.str = ...,
        font_night_color: builtins.str = ...,
        font_day_color: builtins.str = ...,
        rank_content: builtins.str = ...,
        rank_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bkg_day_color", b"bkg_day_color", "bkg_night_color", b"bkg_night_color", "font_day_color", b"font_day_color", "font_night_color", b"font_night_color", "icon_url_day", b"icon_url_day", "icon_url_night", b"icon_url_night", "rank_content", b"rank_content", "rank_link", b"rank_link"]) -> None: ...

global___RankInfo = RankInfo

@typing_extensions.final
class ReasonStyle(google.protobuf.message.Message):
    """推荐理由样式"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    text_color: builtins.str
    """日间模式文字"""
    bg_color: builtins.str
    """"""
    border_color: builtins.str
    """"""
    text_color_night: builtins.str
    """夜间模式文字"""
    bg_color_night: builtins.str
    """"""
    border_color_night: builtins.str
    """"""
    bg_style: builtins.int
    """1:填充 2:描边 3:填充 + 描边 4:背景不填充 + 背景不描边"""
    selected: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        bg_color: builtins.str = ...,
        border_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        border_color_night: builtins.str = ...,
        bg_style: builtins.int = ...,
        selected: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_style", b"bg_style", "border_color", b"border_color", "border_color_night", b"border_color_night", "selected", b"selected", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___ReasonStyle = ReasonStyle

@typing_extensions.final
class RecDislike(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    CLOSED_SUB_TITLE_FIELD_NUMBER: builtins.int
    PASTE_TEXT_FIELD_NUMBER: builtins.int
    CLOSED_PASTE_TEXT_FIELD_NUMBER: builtins.int
    DISLIKE_REASON_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    CLOSED_TOAST_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    sub_title: builtins.str
    """"""
    closed_sub_title: builtins.str
    """"""
    paste_text: builtins.str
    """"""
    closed_paste_text: builtins.str
    """"""
    @property
    def dislike_reason(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReasons]:
        """"""
    toast: builtins.str
    """"""
    closed_toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        sub_title: builtins.str = ...,
        closed_sub_title: builtins.str = ...,
        paste_text: builtins.str = ...,
        closed_paste_text: builtins.str = ...,
        dislike_reason: collections.abc.Iterable[global___DislikeReasons] | None = ...,
        toast: builtins.str = ...,
        closed_toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["closed_paste_text", b"closed_paste_text", "closed_sub_title", b"closed_sub_title", "closed_toast", b"closed_toast", "dislike_reason", b"dislike_reason", "paste_text", b"paste_text", "sub_title", b"sub_title", "title", b"title", "toast", b"toast"]) -> None: ...

global___RecDislike = RecDislike

@typing_extensions.final
class RecThreePoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISLIKE_FIELD_NUMBER: builtins.int
    FEEDBACK_FIELD_NUMBER: builtins.int
    WATCH_LATER_FIELD_NUMBER: builtins.int
    @property
    def dislike(self) -> global___RecDislike:
        """"""
    @property
    def feedback(self) -> global___RecDislike:
        """"""
    watch_later: builtins.bool
    """"""
    def __init__(
        self,
        *,
        dislike: global___RecDislike | None = ...,
        feedback: global___RecDislike | None = ...,
        watch_later: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dislike", b"dislike", "feedback", b"feedback"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike", b"dislike", "feedback", b"feedback", "watch_later", b"watch_later"]) -> None: ...

global___RecThreePoint = RecThreePoint

@typing_extensions.final
class RefreshPage(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REFRESHABLE_FIELD_NUMBER: builtins.int
    REFRESH_ICON_FIELD_NUMBER: builtins.int
    REFRESH_TEXT_FIELD_NUMBER: builtins.int
    REFRESH_SHOW_FIELD_NUMBER: builtins.int
    refreshable: builtins.int
    """"""
    refresh_icon: builtins.int
    """"""
    refresh_text: builtins.str
    """"""
    refresh_show: builtins.float
    """"""
    def __init__(
        self,
        *,
        refreshable: builtins.int = ...,
        refresh_icon: builtins.int = ...,
        refresh_text: builtins.str = ...,
        refresh_show: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["refresh_icon", b"refresh_icon", "refresh_show", b"refresh_show", "refresh_text", b"refresh_text", "refreshable", b"refreshable"]) -> None: ...

global___RefreshPage = RefreshPage

@typing_extensions.final
class Relate(google.protobuf.message.Message):
    """相关推荐项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    RATING_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    RATING_COUNT_FIELD_NUMBER: builtins.int
    TAG_NAME_FIELD_NUMBER: builtins.int
    PACK_INFO_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    NEW_CARD_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    COVER_GIF_FIELD_NUMBER: builtins.int
    CM_FIELD_NUMBER: builtins.int
    RESERVE_STATUS_FIELD_NUMBER: builtins.int
    RCMD_REASON_EXTRA_FIELD_NUMBER: builtins.int
    REC_THREE_POINT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    MATERIAL_ID_FIELD_NUMBER: builtins.int
    FROM_SOURCE_TYPE_FIELD_NUMBER: builtins.int
    FROM_SOURCE_ID_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    BADGE_STYLE_FIELD_NUMBER: builtins.int
    POWER_ICON_STYLE_FIELD_NUMBER: builtins.int
    RESERVE_STATUS_TEXT_FIELD_NUMBER: builtins.int
    DISLIKE_REPORT_DATA_FIELD_NUMBER: builtins.int
    RANK_INFO_GAME_FIELD_NUMBER: builtins.int
    FIRST_FRAME_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    pic: builtins.str
    """封面url"""
    title: builtins.str
    """标题"""
    @property
    def author(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Author:
        """UP主信息"""
    @property
    def stat(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Stat:
        """稿件状态数"""
    duration: builtins.int
    """时长"""
    goto: builtins.str
    """跳转类型
    special:pgc视频 av:稿件视频 cm:广告 game:游戏
    """
    param: builtins.str
    """参数（如av号等）"""
    uri: builtins.str
    """跳转uri"""
    jump_url: builtins.str
    """"""
    rating: builtins.float
    """评分"""
    reserve: builtins.str
    """"""
    desc: builtins.str
    """备注"""
    rcmd_reason: builtins.str
    """"""
    badge: builtins.str
    """标志文字"""
    cid: builtins.int
    """1P cid"""
    season_type: builtins.int
    """"""
    rating_count: builtins.int
    """"""
    tag_name: builtins.str
    """标签文案"""
    @property
    def pack_info(self) -> global___PackInfo:
        """游戏礼包信息"""
    @property
    def notice(self) -> global___Notice:
        """"""
    @property
    def button(self) -> global___Button:
        """按钮信息"""
    trackid: builtins.str
    """spm追踪id"""
    new_card: builtins.int
    """游戏卡片新样式"""
    @property
    def rcmd_reason_style(self) -> global___ReasonStyle:
        """推荐理由样式"""
    cover_gif: builtins.str
    """"""
    @property
    def cm(self) -> global___CM:
        """广告"""
    reserve_status: builtins.int
    """游戏卡字段
    0:下载 1:预约(跳过详情) 2:预约 3:测试 4:测试+预约 5:跳过详情页
    """
    rcmd_reason_extra: builtins.str
    """"""
    @property
    def rec_three_point(self) -> global___RecThreePoint:
        """"""
    unique_id: builtins.str
    """"""
    material_id: builtins.int
    """"""
    from_source_type: builtins.int
    """"""
    from_source_id: builtins.str
    """"""
    @property
    def dimension(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Dimension:
        """"""
    cover: builtins.str
    """"""
    @property
    def badge_style(self) -> global___ReasonStyle:
        """"""
    @property
    def power_icon_style(self) -> global___PowerIconStyle:
        """"""
    reserve_status_text: builtins.str
    """"""
    dislike_report_data: builtins.str
    """"""
    @property
    def rank_info_game(self) -> global___RankInfo:
        """"""
    first_frame: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        pic: builtins.str = ...,
        title: builtins.str = ...,
        author: bilibili.app.archive.v1.archive_pb2.Author | None = ...,
        stat: bilibili.app.archive.v1.archive_pb2.Stat | None = ...,
        duration: builtins.int = ...,
        goto: builtins.str = ...,
        param: builtins.str = ...,
        uri: builtins.str = ...,
        jump_url: builtins.str = ...,
        rating: builtins.float = ...,
        reserve: builtins.str = ...,
        desc: builtins.str = ...,
        rcmd_reason: builtins.str = ...,
        badge: builtins.str = ...,
        cid: builtins.int = ...,
        season_type: builtins.int = ...,
        rating_count: builtins.int = ...,
        tag_name: builtins.str = ...,
        pack_info: global___PackInfo | None = ...,
        notice: global___Notice | None = ...,
        button: global___Button | None = ...,
        trackid: builtins.str = ...,
        new_card: builtins.int = ...,
        rcmd_reason_style: global___ReasonStyle | None = ...,
        cover_gif: builtins.str = ...,
        cm: global___CM | None = ...,
        reserve_status: builtins.int = ...,
        rcmd_reason_extra: builtins.str = ...,
        rec_three_point: global___RecThreePoint | None = ...,
        unique_id: builtins.str = ...,
        material_id: builtins.int = ...,
        from_source_type: builtins.int = ...,
        from_source_id: builtins.str = ...,
        dimension: bilibili.app.archive.v1.archive_pb2.Dimension | None = ...,
        cover: builtins.str = ...,
        badge_style: global___ReasonStyle | None = ...,
        power_icon_style: global___PowerIconStyle | None = ...,
        reserve_status_text: builtins.str = ...,
        dislike_report_data: builtins.str = ...,
        rank_info_game: global___RankInfo | None = ...,
        first_frame: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "badge_style", b"badge_style", "button", b"button", "cm", b"cm", "dimension", b"dimension", "notice", b"notice", "pack_info", b"pack_info", "power_icon_style", b"power_icon_style", "rank_info_game", b"rank_info_game", "rcmd_reason_style", b"rcmd_reason_style", "rec_three_point", b"rec_three_point", "stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "author", b"author", "badge", b"badge", "badge_style", b"badge_style", "button", b"button", "cid", b"cid", "cm", b"cm", "cover", b"cover", "cover_gif", b"cover_gif", "desc", b"desc", "dimension", b"dimension", "dislike_report_data", b"dislike_report_data", "duration", b"duration", "first_frame", b"first_frame", "from", b"from", "from_source_id", b"from_source_id", "from_source_type", b"from_source_type", "goto", b"goto", "jump_url", b"jump_url", "material_id", b"material_id", "new_card", b"new_card", "notice", b"notice", "pack_info", b"pack_info", "param", b"param", "pic", b"pic", "power_icon_style", b"power_icon_style", "rank_info_game", b"rank_info_game", "rating", b"rating", "rating_count", b"rating_count", "rcmd_reason", b"rcmd_reason", "rcmd_reason_extra", b"rcmd_reason_extra", "rcmd_reason_style", b"rcmd_reason_style", "rec_three_point", b"rec_three_point", "reserve", b"reserve", "reserve_status", b"reserve_status", "reserve_status_text", b"reserve_status_text", "season_type", b"season_type", "stat", b"stat", "tag_name", b"tag_name", "title", b"title", "trackid", b"trackid", "unique_id", b"unique_id", "uri", b"uri"]) -> None: ...

global___Relate = Relate

@typing_extensions.final
class RelateItem(google.protobuf.message.Message):
    """相关推荐内容"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    url: builtins.str
    """跳链"""
    cover: builtins.str
    """封面"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        cover: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "url", b"url"]) -> None: ...

global___RelateItem = RelateItem

@typing_extensions.final
class RelatesFeedReply(google.protobuf.message.Message):
    """播放页推荐IFS-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    HAS_NEXT_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relate]:
        """"""
    has_next: builtins.bool
    """"""
    @property
    def pagination(self) -> bilireq.grpc.protos.bilibili.pagination.pagination_pb2.PaginationReply:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___Relate] | None = ...,
        has_next: builtins.bool = ...,
        pagination: bilibili.pagination.pagination_pb2.PaginationReply | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_next", b"has_next", "list", b"list", "pagination", b"pagination"]) -> None: ...

global___RelatesFeedReply = RelatesFeedReply

@typing_extensions.final
class RelatesFeedReq(google.protobuf.message.Message):
    """播放页推荐IFS-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    RELATES_PAGE_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    FROM_TRACK_ID_FIELD_NUMBER: builtins.int
    BIZ_EXTRA_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    AD_EXTRA_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    REFRESH_NUM_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    spmid: builtins.str
    """"""
    from_spmid: builtins.str
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
    relates_page: builtins.int
    """"""
    session_id: builtins.str
    """"""
    autoplay: builtins.int
    """"""
    from_track_id: builtins.str
    """"""
    biz_extra: builtins.str
    """"""
    device_type: builtins.int
    """"""
    ad_extra: builtins.str
    """"""
    @property
    def pagination(self) -> bilireq.grpc.protos.bilibili.pagination.pagination_pb2.Pagination:
        """"""
    refresh_num: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        player_args: bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        relates_page: builtins.int = ...,
        session_id: builtins.str = ...,
        autoplay: builtins.int = ...,
        from_track_id: builtins.str = ...,
        biz_extra: builtins.str = ...,
        device_type: builtins.int = ...,
        ad_extra: builtins.str = ...,
        pagination: bilibili.pagination.pagination_pb2.Pagination | None = ...,
        refresh_num: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra", b"ad_extra", "aid", b"aid", "autoplay", b"autoplay", "biz_extra", b"biz_extra", "bvid", b"bvid", "device_type", b"device_type", "from", b"from", "from_spmid", b"from_spmid", "from_track_id", b"from_track_id", "pagination", b"pagination", "player_args", b"player_args", "refresh_num", b"refresh_num", "relates_page", b"relates_page", "session_id", b"session_id", "spmid", b"spmid"]) -> None: ...

global___RelatesFeedReq = RelatesFeedReq

@typing_extensions.final
class RelateTab(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """"""
    title: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "title", b"title"]) -> None: ...

global___RelateTab = RelateTab

@typing_extensions.final
class ReplyStyle(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BADGE_URL_FIELD_NUMBER: builtins.int
    BADGE_TEXT_FIELD_NUMBER: builtins.int
    BADGE_TYPE_FIELD_NUMBER: builtins.int
    badge_url: builtins.str
    """"""
    badge_text: builtins.str
    """"""
    badge_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        badge_url: builtins.str = ...,
        badge_text: builtins.str = ...,
        badge_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge_text", b"badge_text", "badge_type", b"badge_type", "badge_url", b"badge_url"]) -> None: ...

global___ReplyStyle = ReplyStyle

@typing_extensions.final
class ReqUser(google.protobuf.message.Message):
    """用户操作状态"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTENTION_FIELD_NUMBER: builtins.int
    GUEST_ATTENTION_FIELD_NUMBER: builtins.int
    FAVORITE_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    ATTENTION_LEVEL_FIELD_NUMBER: builtins.int
    FAV_SEASON_FIELD_NUMBER: builtins.int
    ELEC_PLUS_BTN_FIELD_NUMBER: builtins.int
    attention: builtins.int
    """用户是否关注UP"""
    guest_attention: builtins.int
    """UP是否关注用户"""
    favorite: builtins.int
    """是否收藏"""
    like: builtins.int
    """是否点赞"""
    dislike: builtins.int
    """是否点踩"""
    coin: builtins.int
    """是否投币"""
    attention_level: builtins.int
    """关注等级"""
    fav_season: builtins.int
    """是否收藏合集"""
    @property
    def elec_plus_btn(self) -> global___Button:
        """"""
    def __init__(
        self,
        *,
        attention: builtins.int = ...,
        guest_attention: builtins.int = ...,
        favorite: builtins.int = ...,
        like: builtins.int = ...,
        dislike: builtins.int = ...,
        coin: builtins.int = ...,
        attention_level: builtins.int = ...,
        fav_season: builtins.int = ...,
        elec_plus_btn: global___Button | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["elec_plus_btn", b"elec_plus_btn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention", b"attention", "attention_level", b"attention_level", "coin", b"coin", "dislike", b"dislike", "elec_plus_btn", b"elec_plus_btn", "fav_season", b"fav_season", "favorite", b"favorite", "guest_attention", b"guest_attention", "like", b"like"]) -> None: ...

global___ReqUser = ReqUser

@typing_extensions.final
class ReserveReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVE_ID_FIELD_NUMBER: builtins.int
    reserve_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        reserve_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reserve_id", b"reserve_id"]) -> None: ...

global___ReserveReply = ReserveReply

@typing_extensions.final
class ReserveReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVE_ID_FIELD_NUMBER: builtins.int
    RESERVE_ACTION_FIELD_NUMBER: builtins.int
    UP_ID_FIELD_NUMBER: builtins.int
    reserve_id: builtins.int
    """"""
    reserve_action: builtins.int
    """"""
    up_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        reserve_id: builtins.int = ...,
        reserve_action: builtins.int = ...,
        up_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reserve_action", b"reserve_action", "reserve_id", b"reserve_id", "up_id", b"up_id"]) -> None: ...

global___ReserveReq = ReserveReq

@typing_extensions.final
class Restriction(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_TEENAGERS_FIELD_NUMBER: builtins.int
    IS_LESSONS_FIELD_NUMBER: builtins.int
    IS_REVIEW_FIELD_NUMBER: builtins.int
    DISABLE_RCMD_FIELD_NUMBER: builtins.int
    is_teenagers: builtins.bool
    """"""
    is_lessons: builtins.bool
    """"""
    is_review: builtins.bool
    """"""
    disable_rcmd: builtins.bool
    """"""
    def __init__(
        self,
        *,
        is_teenagers: builtins.bool = ...,
        is_lessons: builtins.bool = ...,
        is_review: builtins.bool = ...,
        disable_rcmd: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_rcmd", b"disable_rcmd", "is_lessons", b"is_lessons", "is_review", b"is_review", "is_teenagers", b"is_teenagers"]) -> None: ...

global___Restriction = Restriction

@typing_extensions.final
class Season(google.protobuf.message.Message):
    """剧集信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_DOWNLOAD_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    IS_JUMP_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    IS_FINISH_FIELD_NUMBER: builtins.int
    NEWEST_EP_ID_FIELD_NUMBER: builtins.int
    NEWEST_EP_INDEX_FIELD_NUMBER: builtins.int
    TOTAL_COUNT_FIELD_NUMBER: builtins.int
    WEEKDAY_FIELD_NUMBER: builtins.int
    USER_SEASON_FIELD_NUMBER: builtins.int
    PLAYER_FIELD_NUMBER: builtins.int
    OGV_PLAYURL_FIELD_NUMBER: builtins.int
    allow_download: builtins.str
    """"""
    season_id: builtins.int
    """剧集ssid"""
    is_jump: builtins.int
    """是否重定向跳转"""
    title: builtins.str
    """剧集标题"""
    cover: builtins.str
    """剧集封面url"""
    is_finish: builtins.int
    """剧集是否完结"""
    newest_ep_id: builtins.int
    """最新一话epid"""
    newest_ep_index: builtins.str
    """最新一话标题"""
    total_count: builtins.int
    """总集数"""
    weekday: builtins.int
    """更新星期日"""
    @property
    def user_season(self) -> global___UserSeason:
        """用户追番标志"""
    @property
    def player(self) -> global___SeasonPlayer:
        """"""
    ogv_playurl: builtins.str
    """单集页面url"""
    def __init__(
        self,
        *,
        allow_download: builtins.str = ...,
        season_id: builtins.int = ...,
        is_jump: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        is_finish: builtins.int = ...,
        newest_ep_id: builtins.int = ...,
        newest_ep_index: builtins.str = ...,
        total_count: builtins.int = ...,
        weekday: builtins.int = ...,
        user_season: global___UserSeason | None = ...,
        player: global___SeasonPlayer | None = ...,
        ogv_playurl: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player", b"player", "user_season", b"user_season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_download", b"allow_download", "cover", b"cover", "is_finish", b"is_finish", "is_jump", b"is_jump", "newest_ep_id", b"newest_ep_id", "newest_ep_index", b"newest_ep_index", "ogv_playurl", b"ogv_playurl", "player", b"player", "season_id", b"season_id", "title", b"title", "total_count", b"total_count", "user_season", b"user_season", "weekday", b"weekday"]) -> None: ...

global___Season = Season

@typing_extensions.final
class SeasonActivityRecordReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_FIELD_NUMBER: builtins.int
    @property
    def activity(self) -> global___UgcSeasonActivity:
        """"""
    def __init__(
        self,
        *,
        activity: global___UgcSeasonActivity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity", b"activity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity", b"activity"]) -> None: ...

global___SeasonActivityRecordReply = SeasonActivityRecordReply

@typing_extensions.final
class SeasonActivityRecordReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    activity_id: builtins.int
    """"""
    action: builtins.int
    """"""
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    scene: builtins.int
    """"""
    spmid: builtins.str
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        activity_id: builtins.int = ...,
        action: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        scene: builtins.int = ...,
        spmid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "activity_id", b"activity_id", "aid", b"aid", "cid", b"cid", "scene", b"scene", "season_id", b"season_id", "spmid", b"spmid"]) -> None: ...

global___SeasonActivityRecordReq = SeasonActivityRecordReq

@typing_extensions.final
class SeasonPlayer(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    VID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    vid: builtins.str
    """"""
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        vid: builtins.str = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "from", b"from", "vid", b"vid"]) -> None: ...

global___SeasonPlayer = SeasonPlayer

@typing_extensions.final
class SeasonReply(google.protobuf.message.Message):
    """合集详情页-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_FIELD_NUMBER: builtins.int
    @property
    def season(self) -> global___UgcSeason:
        """合集信息"""
    def __init__(
        self,
        *,
        season: global___UgcSeason | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["season", b"season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["season", b"season"]) -> None: ...

global___SeasonReply = SeasonReply

@typing_extensions.final
class SeasonReq(google.protobuf.message.Message):
    """合集详情页-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """合集id"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id", b"season_id"]) -> None: ...

global___SeasonReq = SeasonReq

@typing_extensions.final
class SeasonShow(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUTTON_TEXT_FIELD_NUMBER: builtins.int
    JOIN_TEXT_FIELD_NUMBER: builtins.int
    RULE_TEXT_FIELD_NUMBER: builtins.int
    CHECKIN_TEXT_FIELD_NUMBER: builtins.int
    CHECKIN_PROMPT_FIELD_NUMBER: builtins.int
    button_text: builtins.str
    """"""
    join_text: builtins.str
    """"""
    rule_text: builtins.str
    """"""
    checkin_text: builtins.str
    """"""
    checkin_prompt: builtins.str
    """"""
    def __init__(
        self,
        *,
        button_text: builtins.str = ...,
        join_text: builtins.str = ...,
        rule_text: builtins.str = ...,
        checkin_text: builtins.str = ...,
        checkin_prompt: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_text", b"button_text", "checkin_prompt", b"checkin_prompt", "checkin_text", b"checkin_text", "join_text", b"join_text", "rule_text", b"rule_text"]) -> None: ...

global___SeasonShow = SeasonShow

@typing_extensions.final
class SeasonWidgetExposeReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    activity_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        activity_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "season_id", b"season_id"]) -> None: ...

global___SeasonWidgetExposeReply = SeasonWidgetExposeReply

@typing_extensions.final
class SeasonWidgetExposeReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    type: builtins.int
    """"""
    season_id: builtins.int
    """"""
    activity_id: builtins.int
    """"""
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    scene: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        type: builtins.int = ...,
        season_id: builtins.int = ...,
        activity_id: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        scene: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "aid", b"aid", "cid", b"cid", "mid", b"mid", "scene", b"scene", "season_id", b"season_id", "type", b"type"]) -> None: ...

global___SeasonWidgetExposeReq = SeasonWidgetExposeReq

@typing_extensions.final
class Section(google.protobuf.message.Message):
    """视频合集小节信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EPISODES_FIELD_NUMBER: builtins.int
    id: builtins.int
    """小节id"""
    title: builtins.str
    """小节标题"""
    type: builtins.int
    """小节类型
    0:其他 1:正片
    """
    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Episode]:
        """单话列表"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        title: builtins.str = ...,
        type: builtins.int = ...,
        episodes: collections.abc.Iterable[global___Episode] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["episodes", b"episodes", "id", b"id", "title", b"title", "type", b"type"]) -> None: ...

global___Section = Section

@typing_extensions.final
class ShortFormVideoDownloadReply(google.protobuf.message.Message):
    """短视频下载-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAS_DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    BACKUP_DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    has_download_url: builtins.bool
    """是否有下载分享按钮"""
    download_url: builtins.str
    """下载url"""
    md5: builtins.str
    """文件md5"""
    size: builtins.int
    """文件大小(单位为Byte)"""
    backup_download_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        has_download_url: builtins.bool = ...,
        download_url: builtins.str = ...,
        md5: builtins.str = ...,
        size: builtins.int = ...,
        backup_download_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_download_url", b"backup_download_url", "download_url", b"download_url", "has_download_url", b"has_download_url", "md5", b"md5", "size", b"size"]) -> None: ...

global___ShortFormVideoDownloadReply = ShortFormVideoDownloadReply

@typing_extensions.final
class ShortFormVideoDownloadReq(google.protobuf.message.Message):
    """短视频下载-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    RESTRICTION_FIELD_NUMBER: builtins.int
    TF_ISP_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""
    cid: builtins.int
    """视频cid"""
    mid: builtins.int
    """用户mid"""
    buvid: builtins.str
    """设备buvid"""
    mobi_app: builtins.str
    """移动端包类型"""
    build: builtins.int
    """移动端版本号"""
    device: builtins.str
    """运行设备"""
    platform: builtins.str
    """平台"""
    spmid: builtins.str
    """当前页面spm"""
    @property
    def restriction(self) -> global___Restriction:
        """"""
    tf_isp: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        mid: builtins.int = ...,
        buvid: builtins.str = ...,
        mobi_app: builtins.str = ...,
        build: builtins.int = ...,
        device: builtins.str = ...,
        platform: builtins.str = ...,
        spmid: builtins.str = ...,
        restriction: global___Restriction | None = ...,
        tf_isp: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["restriction", b"restriction"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "build", b"build", "buvid", b"buvid", "cid", b"cid", "device", b"device", "mid", b"mid", "mobi_app", b"mobi_app", "platform", b"platform", "restriction", b"restriction", "spmid", b"spmid", "tf_isp", b"tf_isp"]) -> None: ...

global___ShortFormVideoDownloadReq = ShortFormVideoDownloadReq

@typing_extensions.final
class SpecialCell(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    ICON_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    CELL_TYPE_FIELD_NUMBER: builtins.int
    CELL_BGCOLOR_FIELD_NUMBER: builtins.int
    CELL_BGCOLOR_NIGHT_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    PAGE_TITLE_FIELD_NUMBER: builtins.int
    JUMP_TYPE_FIELD_NUMBER: builtins.int
    END_ICON_FIELD_NUMBER: builtins.int
    END_ICON_NIGHT_FIELD_NUMBER: builtins.int
    NOTES_COUNT_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """"""
    icon_night: builtins.str
    """"""
    text: builtins.str
    """"""
    text_color: builtins.str
    """"""
    text_color_night: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    cell_type: builtins.str
    """"""
    cell_bgcolor: builtins.str
    """"""
    cell_bgcolor_night: builtins.str
    """"""
    param: builtins.str
    """"""
    page_title: builtins.str
    """"""
    jump_type: builtins.str
    """"""
    end_icon: builtins.str
    """"""
    end_icon_night: builtins.str
    """"""
    notes_count: builtins.int
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        icon_night: builtins.str = ...,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        jump_url: builtins.str = ...,
        cell_type: builtins.str = ...,
        cell_bgcolor: builtins.str = ...,
        cell_bgcolor_night: builtins.str = ...,
        param: builtins.str = ...,
        page_title: builtins.str = ...,
        jump_type: builtins.str = ...,
        end_icon: builtins.str = ...,
        end_icon_night: builtins.str = ...,
        notes_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cell_bgcolor", b"cell_bgcolor", "cell_bgcolor_night", b"cell_bgcolor_night", "cell_type", b"cell_type", "end_icon", b"end_icon", "end_icon_night", b"end_icon_night", "icon", b"icon", "icon_night", b"icon_night", "jump_type", b"jump_type", "jump_url", b"jump_url", "notes_count", b"notes_count", "page_title", b"page_title", "param", b"param", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___SpecialCell = SpecialCell

@typing_extensions.final
class Staff(google.protobuf.message.Message):
    """合作成员信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    ATTENTION_FIELD_NUMBER: builtins.int
    LABEL_STYLE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """成员mid"""
    title: builtins.str
    """成员角色"""
    face: builtins.str
    """成员头像url"""
    name: builtins.str
    """成员昵称"""
    @property
    def official_verify(self) -> global___OfficialVerify:
        """成员官方信息"""
    @property
    def vip(self) -> global___Vip:
        """成员会员信息"""
    attention: builtins.int
    """是否关注该成员"""
    label_style: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        title: builtins.str = ...,
        face: builtins.str = ...,
        name: builtins.str = ...,
        official_verify: global___OfficialVerify | None = ...,
        vip: global___Vip | None = ...,
        attention: builtins.int = ...,
        label_style: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official_verify", b"official_verify", "vip", b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention", b"attention", "face", b"face", "label_style", b"label_style", "mid", b"mid", "name", b"name", "official_verify", b"official_verify", "title", b"title", "vip", b"vip"]) -> None: ...

global___Staff = Staff

@typing_extensions.final
class StandardCard(google.protobuf.message.Message):
    """标准卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    BUTTON_SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SHOW_SELECTED_FIELD_NUMBER: builtins.int
    title: builtins.str
    """卡片文案"""
    button_title: builtins.str
    """按钮文字 未操作"""
    button_selected_title: builtins.str
    """按钮文字 已操作"""
    show_selected: builtins.bool
    """已操作态是否显示"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        button_title: builtins.str = ...,
        button_selected_title: builtins.str = ...,
        show_selected: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_selected_title", b"button_selected_title", "button_title", b"button_title", "show_selected", b"show_selected", "title", b"title"]) -> None: ...

global___StandardCard = StandardCard

@typing_extensions.final
class subTFPanel(google.protobuf.message.Message):
    """免流子面板定制化配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RIGHT_BTN_IMG_FIELD_NUMBER: builtins.int
    RIGHT_BTN_TEXT_FIELD_NUMBER: builtins.int
    RIGHT_BTN_TEXT_COLOR_FIELD_NUMBER: builtins.int
    RIGHT_BTN_LINK_FIELD_NUMBER: builtins.int
    MAIN_LABEL_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    right_btn_img: builtins.str
    """右侧按钮素材"""
    right_btn_text: builtins.str
    """右侧按钮文案"""
    right_btn_text_color: builtins.str
    """右侧按钮字体颜色"""
    right_btn_link: builtins.str
    """右侧按钮跳转链接"""
    main_label: builtins.str
    """中心主文案内容"""
    operator: builtins.str
    """运营商"""
    def __init__(
        self,
        *,
        right_btn_img: builtins.str = ...,
        right_btn_text: builtins.str = ...,
        right_btn_text_color: builtins.str = ...,
        right_btn_link: builtins.str = ...,
        main_label: builtins.str = ...,
        operator: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["main_label", b"main_label", "operator", b"operator", "right_btn_img", b"right_btn_img", "right_btn_link", b"right_btn_link", "right_btn_text", b"right_btn_text", "right_btn_text_color", b"right_btn_text_color"]) -> None: ...

global___subTFPanel = subTFPanel

@typing_extensions.final
class Tab(google.protobuf.message.Message):
    """TAB"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_FIELD_NUMBER: builtins.int
    OTYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_SELECTED_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    AD_TAB_INFO_FIELD_NUMBER: builtins.int
    background: builtins.str
    """背景图片"""
    otype: global___TabOtype.ValueType
    """跳转类型"""
    oid: builtins.int
    """类型id"""
    uri: builtins.str
    """跳转url"""
    style: global___TabStyle.ValueType
    """样式"""
    text: builtins.str
    """文字"""
    text_color: builtins.str
    """未选中态字色"""
    text_color_selected: builtins.str
    """选中态字色"""
    pic: builtins.str
    """图片"""
    id: builtins.int
    """后台配置自增"""
    @property
    def ad_tab_info(self) -> google.protobuf.any_pb2.Any:
        """"""
    def __init__(
        self,
        *,
        background: builtins.str = ...,
        otype: global___TabOtype.ValueType = ...,
        oid: builtins.int = ...,
        uri: builtins.str = ...,
        style: global___TabStyle.ValueType = ...,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_selected: builtins.str = ...,
        pic: builtins.str = ...,
        id: builtins.int = ...,
        ad_tab_info: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_tab_info", b"ad_tab_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_tab_info", b"ad_tab_info", "background", b"background", "id", b"id", "oid", b"oid", "otype", b"otype", "pic", b"pic", "style", b"style", "text", b"text", "text_color", b"text_color", "text_color_selected", b"text_color_selected", "uri", b"uri"]) -> None: ...

global___Tab = Tab

@typing_extensions.final
class Tag(google.protobuf.message.Message):
    """TAG信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LIKES_FIELD_NUMBER: builtins.int
    HATES_FIELD_NUMBER: builtins.int
    LIKED_FIELD_NUMBER: builtins.int
    HATED_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TAG_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """TAD id"""
    name: builtins.str
    """TAG名"""
    likes: builtins.int
    """"""
    hates: builtins.int
    """"""
    liked: builtins.int
    """"""
    hated: builtins.int
    """"""
    uri: builtins.str
    """TAG页面uri"""
    tag_type: builtins.str
    """TAG类型
    common:普通 new:话题 act:活动
    """
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        likes: builtins.int = ...,
        hates: builtins.int = ...,
        liked: builtins.int = ...,
        hated: builtins.int = ...,
        uri: builtins.str = ...,
        tag_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hated", b"hated", "hates", b"hates", "id", b"id", "liked", b"liked", "likes", b"likes", "name", b"name", "tag_type", b"tag_type", "uri", b"uri"]) -> None: ...

global___Tag = Tag

@typing_extensions.final
class TFPanelCustomized(google.protobuf.message.Message):
    """免流面板定制"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SubPanelEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___subTFPanel: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___subTFPanel | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RIGHT_BTN_IMG_FIELD_NUMBER: builtins.int
    RIGHT_BTN_TEXT_FIELD_NUMBER: builtins.int
    RIGHT_BTN_TEXT_COLOR_FIELD_NUMBER: builtins.int
    RIGHT_BTN_LINK_FIELD_NUMBER: builtins.int
    MAIN_LABEL_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    SUB_PANEL_FIELD_NUMBER: builtins.int
    right_btn_img: builtins.str
    """右侧按钮素材"""
    right_btn_text: builtins.str
    """右侧按钮文案"""
    right_btn_text_color: builtins.str
    """右侧按钮字体颜色"""
    right_btn_link: builtins.str
    """右侧按钮跳转链接"""
    main_label: builtins.str
    """中心主文案内容"""
    operator: builtins.str
    """运营商(cm ct cu)"""
    @property
    def sub_panel(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___subTFPanel]:
        """子面板定制化配置"""
    def __init__(
        self,
        *,
        right_btn_img: builtins.str = ...,
        right_btn_text: builtins.str = ...,
        right_btn_text_color: builtins.str = ...,
        right_btn_link: builtins.str = ...,
        main_label: builtins.str = ...,
        operator: builtins.str = ...,
        sub_panel: collections.abc.Mapping[builtins.str, global___subTFPanel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["main_label", b"main_label", "operator", b"operator", "right_btn_img", b"right_btn_img", "right_btn_link", b"right_btn_link", "right_btn_text", b"right_btn_text", "right_btn_text_color", b"right_btn_text_color", "sub_panel", b"sub_panel"]) -> None: ...

global___TFPanelCustomized = TFPanelCustomized

@typing_extensions.final
class TIcon(google.protobuf.message.Message):
    """TAG图标信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """TAG图标url"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon"]) -> None: ...

global___TIcon = TIcon

@typing_extensions.final
class UgcSeason(google.protobuf.message.Message):
    """UGC视频合集信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    INTRO_FIELD_NUMBER: builtins.int
    SECTIONS_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    LABEL_TEXT_FIELD_NUMBER: builtins.int
    LABEL_TEXT_COLOR_FIELD_NUMBER: builtins.int
    LABEL_BG_COLOR_FIELD_NUMBER: builtins.int
    LABEL_TEXT_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    LABEL_BG_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    DESCRIGHT_FIELD_NUMBER: builtins.int
    EP_COUNT_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    SHOW_CONTINUAL_BUTTON_FIELD_NUMBER: builtins.int
    EP_NUM_FIELD_NUMBER: builtins.int
    SEASON_PAY_FIELD_NUMBER: builtins.int
    GOODS_INFO_FIELD_NUMBER: builtins.int
    PAY_BUTTON_FIELD_NUMBER: builtins.int
    LABEL_TEXT_NEW_FIELD_NUMBER: builtins.int
    ACTIVITY_FIELD_NUMBER: builtins.int
    SEASON_ABILITY_FIELD_NUMBER: builtins.int
    id: builtins.int
    """合集id"""
    title: builtins.str
    """合集标题"""
    cover: builtins.str
    """合集封面url"""
    intro: builtins.str
    """合集简介"""
    @property
    def sections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Section]:
        """小节列表"""
    @property
    def stat(self) -> global___UgcSeasonStat:
        """合集状态数"""
    label_text: builtins.str
    """标签字色"""
    label_text_color: builtins.str
    """标签背景色"""
    label_bg_color: builtins.str
    """标签夜间字色"""
    label_text_night_color: builtins.str
    """标签夜间背景色"""
    label_bg_night_color: builtins.str
    """右侧描述文案"""
    descRight: builtins.str
    """按钮文案"""
    ep_count: builtins.int
    """分集总数"""
    season_type: global___SeasonType.ValueType
    """合集类型"""
    show_continual_button: builtins.bool
    """"""
    ep_num: builtins.int
    """"""
    season_pay: builtins.bool
    """"""
    @property
    def goods_info(self) -> global___GoodsInfo:
        """"""
    @property
    def pay_button(self) -> global___ButtonStyle:
        """"""
    label_text_new: builtins.str
    """"""
    @property
    def activity(self) -> global___UgcSeasonActivity:
        """"""
    @property
    def season_ability(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        intro: builtins.str = ...,
        sections: collections.abc.Iterable[global___Section] | None = ...,
        stat: global___UgcSeasonStat | None = ...,
        label_text: builtins.str = ...,
        label_text_color: builtins.str = ...,
        label_bg_color: builtins.str = ...,
        label_text_night_color: builtins.str = ...,
        label_bg_night_color: builtins.str = ...,
        descRight: builtins.str = ...,
        ep_count: builtins.int = ...,
        season_type: global___SeasonType.ValueType = ...,
        show_continual_button: builtins.bool = ...,
        ep_num: builtins.int = ...,
        season_pay: builtins.bool = ...,
        goods_info: global___GoodsInfo | None = ...,
        pay_button: global___ButtonStyle | None = ...,
        label_text_new: builtins.str = ...,
        activity: global___UgcSeasonActivity | None = ...,
        season_ability: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity", b"activity", "goods_info", b"goods_info", "pay_button", b"pay_button", "stat", b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity", b"activity", "cover", b"cover", "descRight", b"descRight", "ep_count", b"ep_count", "ep_num", b"ep_num", "goods_info", b"goods_info", "id", b"id", "intro", b"intro", "label_bg_color", b"label_bg_color", "label_bg_night_color", b"label_bg_night_color", "label_text", b"label_text", "label_text_color", b"label_text_color", "label_text_new", b"label_text_new", "label_text_night_color", b"label_text_night_color", "pay_button", b"pay_button", "season_ability", b"season_ability", "season_pay", b"season_pay", "season_type", b"season_type", "sections", b"sections", "show_continual_button", b"show_continual_button", "stat", b"stat", "title", b"title"]) -> None: ...

global___UgcSeason = UgcSeason

@typing_extensions.final
class UgcSeasonActivity(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    INTRO_FIELD_NUMBER: builtins.int
    DAY_COUNT_FIELD_NUMBER: builtins.int
    USER_COUNT_FIELD_NUMBER: builtins.int
    JOIN_DEADLINE_FIELD_NUMBER: builtins.int
    ACTIVITY_DEADLINE_FIELD_NUMBER: builtins.int
    CHECKIN_VIEW_TIME_FIELD_NUMBER: builtins.int
    NEW_ACTIVITY_FIELD_NUMBER: builtins.int
    USER_ACTIVITY_FIELD_NUMBER: builtins.int
    SEASON_SHOW_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    oid: builtins.int
    """"""
    activity_id: builtins.int
    """"""
    title: builtins.str
    """"""
    intro: builtins.str
    """"""
    day_count: builtins.int
    """"""
    user_count: builtins.int
    """"""
    join_deadline: builtins.int
    """"""
    activity_deadline: builtins.int
    """"""
    checkin_view_time: builtins.int
    """"""
    new_activity: builtins.bool
    """"""
    @property
    def user_activity(self) -> global___UserActivity:
        """"""
    @property
    def season_show(self) -> global___SeasonShow:
        """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        oid: builtins.int = ...,
        activity_id: builtins.int = ...,
        title: builtins.str = ...,
        intro: builtins.str = ...,
        day_count: builtins.int = ...,
        user_count: builtins.int = ...,
        join_deadline: builtins.int = ...,
        activity_deadline: builtins.int = ...,
        checkin_view_time: builtins.int = ...,
        new_activity: builtins.bool = ...,
        user_activity: global___UserActivity | None = ...,
        season_show: global___SeasonShow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["season_show", b"season_show", "user_activity", b"user_activity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_deadline", b"activity_deadline", "activity_id", b"activity_id", "checkin_view_time", b"checkin_view_time", "day_count", b"day_count", "intro", b"intro", "join_deadline", b"join_deadline", "new_activity", b"new_activity", "oid", b"oid", "season_show", b"season_show", "title", b"title", "type", b"type", "user_activity", b"user_activity", "user_count", b"user_count"]) -> None: ...

global___UgcSeasonActivity = UgcSeasonActivity

@typing_extensions.final
class UgcSeasonStat(google.protobuf.message.Message):
    """ugc视频合集状态数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    NOW_RANK_FIELD_NUMBER: builtins.int
    HIS_RANK_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """合集id"""
    view: builtins.int
    """观看数"""
    danmaku: builtins.int
    """弹幕数"""
    reply: builtins.int
    """评论数"""
    fav: builtins.int
    """收藏数"""
    coin: builtins.int
    """投币数"""
    share: builtins.int
    """分享数"""
    now_rank: builtins.int
    """当前排名"""
    his_rank: builtins.int
    """历史最高排名"""
    like: builtins.int
    """总计点赞"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        view: builtins.int = ...,
        danmaku: builtins.int = ...,
        reply: builtins.int = ...,
        fav: builtins.int = ...,
        coin: builtins.int = ...,
        share: builtins.int = ...,
        now_rank: builtins.int = ...,
        his_rank: builtins.int = ...,
        like: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coin", b"coin", "danmaku", b"danmaku", "fav", b"fav", "his_rank", b"his_rank", "like", b"like", "now_rank", b"now_rank", "reply", b"reply", "season_id", b"season_id", "share", b"share", "view", b"view"]) -> None: ...

global___UgcSeasonStat = UgcSeasonStat

@typing_extensions.final
class UpAct(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    STATEMENT_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    sid: builtins.int
    """"""
    mid: builtins.int
    """"""
    title: builtins.str
    """"""
    statement: builtins.str
    """"""
    image: builtins.str
    """"""
    url: builtins.str
    """"""
    button: builtins.str
    """"""
    def __init__(
        self,
        *,
        sid: builtins.int = ...,
        mid: builtins.int = ...,
        title: builtins.str = ...,
        statement: builtins.str = ...,
        image: builtins.str = ...,
        url: builtins.str = ...,
        button: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "image", b"image", "mid", b"mid", "sid", b"sid", "statement", b"statement", "title", b"title", "url", b"url"]) -> None: ...

global___UpAct = UpAct

@typing_extensions.final
class UpLikeImg(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRE_IMG_FIELD_NUMBER: builtins.int
    SUC_IMG_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    pre_img: builtins.str
    """"""
    suc_img: builtins.str
    """"""
    content: builtins.str
    """"""
    type: builtins.int
    """"""
    def __init__(
        self,
        *,
        pre_img: builtins.str = ...,
        suc_img: builtins.str = ...,
        content: builtins.str = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "pre_img", b"pre_img", "suc_img", b"suc_img", "type", b"type"]) -> None: ...

global___UpLikeImg = UpLikeImg

@typing_extensions.final
class UpperInfos(google.protobuf.message.Message):
    """UP主信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FANS_COUNT_FIELD_NUMBER: builtins.int
    ARC_COUNT_LAST_HALF_YEAR_FIELD_NUMBER: builtins.int
    FIRST_UP_DATES_FIELD_NUMBER: builtins.int
    TOTAL_PLAY_COUNT_FIELD_NUMBER: builtins.int
    fans_count: builtins.int
    """粉丝数"""
    arc_count_last_half_year: builtins.int
    """近半年投稿数"""
    first_up_dates: builtins.int
    """成为UP主时间"""
    total_play_count: builtins.int
    """总播放量"""
    def __init__(
        self,
        *,
        fans_count: builtins.int = ...,
        arc_count_last_half_year: builtins.int = ...,
        first_up_dates: builtins.int = ...,
        total_play_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_count_last_half_year", b"arc_count_last_half_year", "fans_count", b"fans_count", "first_up_dates", b"first_up_dates", "total_play_count", b"total_play_count"]) -> None: ...

global___UpperInfos = UpperInfos

@typing_extensions.final
class UserActivity(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_STATE_FIELD_NUMBER: builtins.int
    LAST_CHECKIN_DATE_FIELD_NUMBER: builtins.int
    CHECKIN_TODAY_FIELD_NUMBER: builtins.int
    USER_DAY_COUNT_FIELD_NUMBER: builtins.int
    USER_VIEW_TIME_FIELD_NUMBER: builtins.int
    PORTRAIT_FIELD_NUMBER: builtins.int
    user_state: builtins.int
    """"""
    last_checkin_date: builtins.int
    """"""
    checkin_today: builtins.int
    """"""
    user_day_count: builtins.int
    """"""
    user_view_time: builtins.int
    """"""
    portrait: builtins.str
    """"""
    def __init__(
        self,
        *,
        user_state: builtins.int = ...,
        last_checkin_date: builtins.int = ...,
        checkin_today: builtins.int = ...,
        user_day_count: builtins.int = ...,
        user_view_time: builtins.int = ...,
        portrait: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["checkin_today", b"checkin_today", "last_checkin_date", b"last_checkin_date", "portrait", b"portrait", "user_day_count", b"user_day_count", "user_state", b"user_state", "user_view_time", b"user_view_time"]) -> None: ...

global___UserActivity = UserActivity

@typing_extensions.final
class UserGarb(google.protobuf.message.Message):
    """用户装扮信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_IMAGE_ANI_CUT_FIELD_NUMBER: builtins.int
    LIKE_TOAST_FIELD_NUMBER: builtins.int
    url_image_ani_cut: builtins.str
    """点赞动画url"""
    like_toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        url_image_ani_cut: builtins.str = ...,
        like_toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["like_toast", b"like_toast", "url_image_ani_cut", b"url_image_ani_cut"]) -> None: ...

global___UserGarb = UserGarb

@typing_extensions.final
class UserSeason(google.protobuf.message.Message):
    """用户追番标志"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTENTION_FIELD_NUMBER: builtins.int
    attention: builtins.str
    """关注状态
    0:未关注 1:已关注
    """
    def __init__(
        self,
        *,
        attention: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention", b"attention"]) -> None: ...

global___UserSeason = UserSeason

@typing_extensions.final
class VideoGuide(google.protobuf.message.Message):
    """视频引导信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTENTION_FIELD_NUMBER: builtins.int
    COMMANDDMS_FIELD_NUMBER: builtins.int
    OPERATION_CARD_FIELD_NUMBER: builtins.int
    OPERATION_CARD_NEW_FIELD_NUMBER: builtins.int
    CONTRACT_CARD_FIELD_NUMBER: builtins.int
    CARDS_SECOND_FIELD_NUMBER: builtins.int
    @property
    def attention(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Attention]:
        """关注按钮卡片"""
    @property
    def commandDms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandDm]:
        """互动弹幕"""
    @property
    def operation_card(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OperationCard]:
        """运营卡片"""
    @property
    def operation_card_new(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OperationCardNew]:
        """运营卡片新版"""
    @property
    def contract_card(self) -> global___ContractCard:
        """契约卡"""
    @property
    def cards_second(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OperationCardV2]:
        """"""
    def __init__(
        self,
        *,
        attention: collections.abc.Iterable[global___Attention] | None = ...,
        commandDms: collections.abc.Iterable[global___CommandDm] | None = ...,
        operation_card: collections.abc.Iterable[global___OperationCard] | None = ...,
        operation_card_new: collections.abc.Iterable[global___OperationCardNew] | None = ...,
        contract_card: global___ContractCard | None = ...,
        cards_second: collections.abc.Iterable[global___OperationCardV2] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["contract_card", b"contract_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention", b"attention", "cards_second", b"cards_second", "commandDms", b"commandDms", "contract_card", b"contract_card", "operation_card", b"operation_card", "operation_card_new", b"operation_card_new"]) -> None: ...

global___VideoGuide = VideoGuide

@typing_extensions.final
class VideoPoint(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LOGO_URL_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""
    to: builtins.int
    """"""
    content: builtins.str
    """"""
    cover: builtins.str
    """"""
    logo_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        to: builtins.int = ...,
        content: builtins.str = ...,
        cover: builtins.str = ...,
        logo_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "cover", b"cover", "from", b"from", "logo_url", b"logo_url", "to", b"to", "type", b"type"]) -> None: ...

global___VideoPoint = VideoPoint

@typing_extensions.final
class VideoShot(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PV_DATA_FIELD_NUMBER: builtins.int
    IMG_X_LEN_FIELD_NUMBER: builtins.int
    IMG_Y_LEN_FIELD_NUMBER: builtins.int
    IMG_X_SIZE_FIELD_NUMBER: builtins.int
    IMG_Y_SIZE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    pv_data: builtins.str
    """"""
    img_x_len: builtins.int
    """"""
    img_y_len: builtins.int
    """"""
    img_x_size: builtins.int
    """"""
    img_y_size: builtins.int
    """"""
    @property
    def image(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    def __init__(
        self,
        *,
        pv_data: builtins.str = ...,
        img_x_len: builtins.int = ...,
        img_y_len: builtins.int = ...,
        img_x_size: builtins.int = ...,
        img_y_size: builtins.int = ...,
        image: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image", b"image", "img_x_len", b"img_x_len", "img_x_size", b"img_x_size", "img_y_len", b"img_y_len", "img_y_size", b"img_y_size", "pv_data", b"pv_data"]) -> None: ...

global___VideoShot = VideoShot

@typing_extensions.final
class ViewMaterial(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """"""
    mid: builtins.int
    """"""
    title: builtins.str
    """"""
    author: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    def __init__(
        self,
        *,
        oid: builtins.int = ...,
        mid: builtins.int = ...,
        title: builtins.str = ...,
        author: builtins.str = ...,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "jump_url", b"jump_url", "mid", b"mid", "oid", b"oid", "title", b"title"]) -> None: ...

global___ViewMaterial = ViewMaterial

@typing_extensions.final
class ViewMaterialReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATERIAL_RES_FIELD_NUMBER: builtins.int
    MATERIAL_LEFT_FIELD_NUMBER: builtins.int
    @property
    def material_res(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MaterialRes]:
        """"""
    @property
    def material_left(self) -> global___MaterialLeft:
        """"""
    def __init__(
        self,
        *,
        material_res: collections.abc.Iterable[global___MaterialRes] | None = ...,
        material_left: global___MaterialLeft | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["material_left", b"material_left"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["material_left", b"material_left", "material_res", b"material_res"]) -> None: ...

global___ViewMaterialReply = ViewMaterialReply

@typing_extensions.final
class ViewMaterialReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "bvid", b"bvid", "cid", b"cid"]) -> None: ...

global___ViewMaterialReq = ViewMaterialReq

@typing_extensions.final
class ViewPage(google.protobuf.message.Message):
    """分P信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    DM_FIELD_NUMBER: builtins.int
    DOWNLOAD_TITLE_FIELD_NUMBER: builtins.int
    DOWNLOAD_SUBTITLE_FIELD_NUMBER: builtins.int
    @property
    def page(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Page:
        """分P基本信息"""
    @property
    def audio(self) -> global___Audio:
        """分P对应的音频稿件"""
    @property
    def dm(self) -> global___DM:
        """分P弹幕信息"""
    download_title: builtins.str
    """下载文案"""
    download_subtitle: builtins.str
    """分P完整标题(视频标题+分P标题)"""
    def __init__(
        self,
        *,
        page: bilibili.app.archive.v1.archive_pb2.Page | None = ...,
        audio: global___Audio | None = ...,
        dm: global___DM | None = ...,
        download_title: builtins.str = ...,
        download_subtitle: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio", b"audio", "dm", b"dm", "page", b"page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "dm", b"dm", "download_subtitle", b"download_subtitle", "download_title", b"download_title", "page", b"page"]) -> None: ...

global___ViewPage = ViewPage

@typing_extensions.final
class ViewProgressReply(google.protobuf.message.Message):
    """稿件播放中数据-回复"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_GUIDE_FIELD_NUMBER: builtins.int
    CHRONOS_FIELD_NUMBER: builtins.int
    ARC_SHOT_FIELD_NUMBER: builtins.int
    POINTS_FIELD_NUMBER: builtins.int
    POINT_MATERIAL_FIELD_NUMBER: builtins.int
    POINT_PERMANENT_FIELD_NUMBER: builtins.int
    BUZZWORD_PERIODS_FIELD_NUMBER: builtins.int
    @property
    def video_guide(self) -> global___VideoGuide:
        """视频引导信息"""
    @property
    def chronos(self) -> global___Chronos:
        """Chronos灰度管理"""
    @property
    def arc_shot(self) -> global___VideoShot:
        """视频快照"""
    @property
    def points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoPoint]:
        """"""
    @property
    def point_material(self) -> global___PointMaterial:
        """"""
    point_permanent: builtins.bool
    """"""
    @property
    def buzzword_periods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BuzzwordConfig]:
        """名词解释列表"""
    def __init__(
        self,
        *,
        video_guide: global___VideoGuide | None = ...,
        chronos: global___Chronos | None = ...,
        arc_shot: global___VideoShot | None = ...,
        points: collections.abc.Iterable[global___VideoPoint] | None = ...,
        point_material: global___PointMaterial | None = ...,
        point_permanent: builtins.bool = ...,
        buzzword_periods: collections.abc.Iterable[global___BuzzwordConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc_shot", b"arc_shot", "chronos", b"chronos", "point_material", b"point_material", "video_guide", b"video_guide"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_shot", b"arc_shot", "buzzword_periods", b"buzzword_periods", "chronos", b"chronos", "point_material", b"point_material", "point_permanent", b"point_permanent", "points", b"points", "video_guide", b"video_guide"]) -> None: ...

global___ViewProgressReply = ViewProgressReply

@typing_extensions.final
class ViewProgressReq(google.protobuf.message.Message):
    """稿件播放中数据-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    MESSAGE_PROTOCOL_FIELD_NUMBER: builtins.int
    SERVICE_KEY_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""
    cid: builtins.int
    """视频cid"""
    up_mid: builtins.int
    """UP主mid"""
    engine_version: builtins.str
    """"""
    message_protocol: builtins.str
    """"""
    service_key: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        up_mid: builtins.int = ...,
        engine_version: builtins.str = ...,
        message_protocol: builtins.str = ...,
        service_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "engine_version", b"engine_version", "message_protocol", b"message_protocol", "service_key", b"service_key", "up_mid", b"up_mid"]) -> None: ...

global___ViewProgressReq = ViewProgressReq

@typing_extensions.final
class ViewReply(google.protobuf.message.Message):
    """视频页信息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TIconEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___TIcon: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___TIcon | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARC_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    OWNER_EXT_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    T_ICON_FIELD_NUMBER: builtins.int
    SEASON_FIELD_NUMBER: builtins.int
    ELEC_RANK_FIELD_NUMBER: builtins.int
    HISTORY_FIELD_NUMBER: builtins.int
    RELATES_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    PLAYER_ICON_FIELD_NUMBER: builtins.int
    VIP_ACTIVE_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    HONOR_FIELD_NUMBER: builtins.int
    RELATE_TAB_FIELD_NUMBER: builtins.int
    ACTIVITY_URL_FIELD_NUMBER: builtins.int
    BGM_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    ARGUE_MSG_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    PLAY_PARAM_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    UGC_SEASON_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    INTERACTION_FIELD_NUMBER: builtins.int
    ECODE_FIELD_NUMBER: builtins.int
    CUSTOM_CONFIG_FIELD_NUMBER: builtins.int
    CMS_FIELD_NUMBER: builtins.int
    CM_CONFIG_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    TF_PANEL_CUSTOMIZED_FIELD_NUMBER: builtins.int
    UP_ACT_FIELD_NUMBER: builtins.int
    USER_GARB_FIELD_NUMBER: builtins.int
    ACTIVITY_SEASON_FIELD_NUMBER: builtins.int
    BADGE_URL_FIELD_NUMBER: builtins.int
    LIVE_ORDER_INFO_FIELD_NUMBER: builtins.int
    DESC_V2_FIELD_NUMBER: builtins.int
    CM_IPAD_FIELD_NUMBER: builtins.int
    STICKER_FIELD_NUMBER: builtins.int
    UP_LIKE_IMG_FIELD_NUMBER: builtins.int
    LIKE_CUSTOM_FIELD_NUMBER: builtins.int
    DESC_TAG_FIELD_NUMBER: builtins.int
    SPECIAL_CELL_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    CM_UNDER_PLAYER_FIELD_NUMBER: builtins.int
    VIDEO_SOURCE_FIELD_NUMBER: builtins.int
    SPECIAL_CELL_NEW_FIELD_NUMBER: builtins.int
    PREMIERE_FIELD_NUMBER: builtins.int
    REFRESH_SPECIAL_CELL_FIELD_NUMBER: builtins.int
    MATERIAL_LEFT_FIELD_NUMBER: builtins.int
    NOTES_COUNT_FIELD_NUMBER: builtins.int
    PULL_ACTION_FIELD_NUMBER: builtins.int
    ARC_EXTRA_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    LIKE_ANIMATION_FIELD_NUMBER: builtins.int
    REPLY_PREFACE_FIELD_NUMBER: builtins.int
    REFRESH_PAGE_FIELD_NUMBER: builtins.int
    COIN_CUSTOM_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2.Arc:
        """稿件信息"""
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ViewPage]:
        """分P信息"""
    @property
    def owner_ext(self) -> global___OnwerExt:
        """UP主扩展信息 ("OnwerExt"为源码中拼写错误)"""
    @property
    def req_user(self) -> global___ReqUser:
        """稿件用户操作状态"""
    @property
    def tag(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]:
        """稿件TAG"""
    @property
    def t_icon(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___TIcon]:
        """TAG对应的图标"""
    @property
    def season(self) -> global___Season:
        """稿件映射的PGC剧集信息"""
    @property
    def elec_rank(self) -> global___ElecRank:
        """充电排行"""
    @property
    def history(self) -> global___History:
        """历史观看进度"""
    @property
    def relates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relate]:
        """视频相关推荐列表"""
    @property
    def dislike(self) -> global___Dislike:
        """不感兴趣原因"""
    @property
    def player_icon(self) -> global___PlayerIcon:
        """播放图标动画配置档"""
    vip_active: builtins.str
    """"""
    bvid: builtins.str
    """稿件bvid"""
    @property
    def honor(self) -> global___Honor:
        """获得荣誉信息"""
    @property
    def relate_tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RelateTab]:
        """相关推荐顶部tab"""
    activity_url: builtins.str
    """参与的活动页面url"""
    @property
    def bgm(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Bgm]:
        """稿件引用bgm列表"""
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """联合投稿成员列表"""
    argue_msg: builtins.str
    """争议信息"""
    short_link: builtins.str
    """短链接"""
    play_param: builtins.int
    """播放实验
    1:相关推荐自动播放
    """
    @property
    def label(self) -> global___Label:
        """标签"""
    @property
    def ugc_season(self) -> global___UgcSeason:
        """UGC视频合集信息"""
    @property
    def config(self) -> global___Config:
        """配置信息"""
    share_subtitle: builtins.str
    """分享副标题(已观看xxx次)"""
    @property
    def interaction(self) -> global___Interaction:
        """互动视频信息"""
    ecode: global___ECode.ValueType
    """错误码
    DEFAULT:正常 CODE404:视频被UP主删除
    """
    @property
    def custom_config(self) -> global___CustomConfig:
        """404页信息"""
    @property
    def cms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CM]:
        """广告"""
    @property
    def cm_config(self) -> global___CMConfig:
        """广告配置"""
    @property
    def tab(self) -> global___Tab:
        """播放页定制tab"""
    @property
    def rank(self) -> global___Rank:
        """排行榜"""
    @property
    def tf_panel_customized(self) -> global___TFPanelCustomized:
        """免流面板定制"""
    @property
    def up_act(self) -> global___UpAct:
        """UP主发起活动"""
    @property
    def user_garb(self) -> global___UserGarb:
        """用户装扮"""
    @property
    def activity_season(self) -> global___ActivitySeason:
        """大型活动合集"""
    badge_url: builtins.str
    """评论样式"""
    @property
    def live_order_info(self) -> global___LiveOrderInfo:
        """直播预约信息"""
    @property
    def desc_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DescV2]:
        """稿件简介v2"""
    @property
    def cm_ipad(self) -> global___CmIpad:
        """"""
    @property
    def sticker(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ViewMaterial]:
        """"""
    @property
    def up_like_img(self) -> global___UpLikeImg:
        """"""
    @property
    def like_custom(self) -> global___LikeCustom:
        """"""
    @property
    def desc_tag(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]:
        """"""
    @property
    def special_cell(self) -> global___SpecialCell:
        """"""
    @property
    def online(self) -> global___Online:
        """"""
    @property
    def cm_under_player(self) -> google.protobuf.any_pb2.Any:
        """"""
    @property
    def video_source(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ViewMaterial]:
        """"""
    @property
    def special_cell_new(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SpecialCell]:
        """"""
    @property
    def premiere(self) -> global___PremiereResource:
        """"""
    refresh_special_cell: builtins.bool
    """"""
    @property
    def material_left(self) -> global___MaterialLeft:
        """"""
    notes_count: builtins.int
    """"""
    @property
    def pull_action(self) -> global___PullClientAction:
        """"""
    @property
    def arc_extra(self) -> global___ArcExtra:
        """"""
    @property
    def pagination(self) -> bilireq.grpc.protos.bilibili.pagination.pagination_pb2.PaginationReply:
        """"""
    @property
    def like_animation(self) -> global___LikeAnimation:
        """"""
    @property
    def reply_preface(self) -> global___ReplyStyle:
        """"""
    @property
    def refresh_page(self) -> global___RefreshPage:
        """"""
    @property
    def coin_custom(self) -> global___CoinCustom:
        """"""
    def __init__(
        self,
        *,
        arc: bilibili.app.archive.v1.archive_pb2.Arc | None = ...,
        pages: collections.abc.Iterable[global___ViewPage] | None = ...,
        owner_ext: global___OnwerExt | None = ...,
        req_user: global___ReqUser | None = ...,
        tag: collections.abc.Iterable[global___Tag] | None = ...,
        t_icon: collections.abc.Mapping[builtins.str, global___TIcon] | None = ...,
        season: global___Season | None = ...,
        elec_rank: global___ElecRank | None = ...,
        history: global___History | None = ...,
        relates: collections.abc.Iterable[global___Relate] | None = ...,
        dislike: global___Dislike | None = ...,
        player_icon: global___PlayerIcon | None = ...,
        vip_active: builtins.str = ...,
        bvid: builtins.str = ...,
        honor: global___Honor | None = ...,
        relate_tab: collections.abc.Iterable[global___RelateTab] | None = ...,
        activity_url: builtins.str = ...,
        bgm: collections.abc.Iterable[global___Bgm] | None = ...,
        staff: collections.abc.Iterable[global___Staff] | None = ...,
        argue_msg: builtins.str = ...,
        short_link: builtins.str = ...,
        play_param: builtins.int = ...,
        label: global___Label | None = ...,
        ugc_season: global___UgcSeason | None = ...,
        config: global___Config | None = ...,
        share_subtitle: builtins.str = ...,
        interaction: global___Interaction | None = ...,
        ecode: global___ECode.ValueType = ...,
        custom_config: global___CustomConfig | None = ...,
        cms: collections.abc.Iterable[global___CM] | None = ...,
        cm_config: global___CMConfig | None = ...,
        tab: global___Tab | None = ...,
        rank: global___Rank | None = ...,
        tf_panel_customized: global___TFPanelCustomized | None = ...,
        up_act: global___UpAct | None = ...,
        user_garb: global___UserGarb | None = ...,
        activity_season: global___ActivitySeason | None = ...,
        badge_url: builtins.str = ...,
        live_order_info: global___LiveOrderInfo | None = ...,
        desc_v2: collections.abc.Iterable[global___DescV2] | None = ...,
        cm_ipad: global___CmIpad | None = ...,
        sticker: collections.abc.Iterable[global___ViewMaterial] | None = ...,
        up_like_img: global___UpLikeImg | None = ...,
        like_custom: global___LikeCustom | None = ...,
        desc_tag: collections.abc.Iterable[global___Tag] | None = ...,
        special_cell: global___SpecialCell | None = ...,
        online: global___Online | None = ...,
        cm_under_player: google.protobuf.any_pb2.Any | None = ...,
        video_source: collections.abc.Iterable[global___ViewMaterial] | None = ...,
        special_cell_new: collections.abc.Iterable[global___SpecialCell] | None = ...,
        premiere: global___PremiereResource | None = ...,
        refresh_special_cell: builtins.bool = ...,
        material_left: global___MaterialLeft | None = ...,
        notes_count: builtins.int = ...,
        pull_action: global___PullClientAction | None = ...,
        arc_extra: global___ArcExtra | None = ...,
        pagination: bilibili.pagination.pagination_pb2.PaginationReply | None = ...,
        like_animation: global___LikeAnimation | None = ...,
        reply_preface: global___ReplyStyle | None = ...,
        refresh_page: global___RefreshPage | None = ...,
        coin_custom: global___CoinCustom | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity_season", b"activity_season", "arc", b"arc", "arc_extra", b"arc_extra", "cm_config", b"cm_config", "cm_ipad", b"cm_ipad", "cm_under_player", b"cm_under_player", "coin_custom", b"coin_custom", "config", b"config", "custom_config", b"custom_config", "dislike", b"dislike", "elec_rank", b"elec_rank", "history", b"history", "honor", b"honor", "interaction", b"interaction", "label", b"label", "like_animation", b"like_animation", "like_custom", b"like_custom", "live_order_info", b"live_order_info", "material_left", b"material_left", "online", b"online", "owner_ext", b"owner_ext", "pagination", b"pagination", "player_icon", b"player_icon", "premiere", b"premiere", "pull_action", b"pull_action", "rank", b"rank", "refresh_page", b"refresh_page", "reply_preface", b"reply_preface", "req_user", b"req_user", "season", b"season", "special_cell", b"special_cell", "tab", b"tab", "tf_panel_customized", b"tf_panel_customized", "ugc_season", b"ugc_season", "up_act", b"up_act", "up_like_img", b"up_like_img", "user_garb", b"user_garb"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_season", b"activity_season", "activity_url", b"activity_url", "arc", b"arc", "arc_extra", b"arc_extra", "argue_msg", b"argue_msg", "badge_url", b"badge_url", "bgm", b"bgm", "bvid", b"bvid", "cm_config", b"cm_config", "cm_ipad", b"cm_ipad", "cm_under_player", b"cm_under_player", "cms", b"cms", "coin_custom", b"coin_custom", "config", b"config", "custom_config", b"custom_config", "desc_tag", b"desc_tag", "desc_v2", b"desc_v2", "dislike", b"dislike", "ecode", b"ecode", "elec_rank", b"elec_rank", "history", b"history", "honor", b"honor", "interaction", b"interaction", "label", b"label", "like_animation", b"like_animation", "like_custom", b"like_custom", "live_order_info", b"live_order_info", "material_left", b"material_left", "notes_count", b"notes_count", "online", b"online", "owner_ext", b"owner_ext", "pages", b"pages", "pagination", b"pagination", "play_param", b"play_param", "player_icon", b"player_icon", "premiere", b"premiere", "pull_action", b"pull_action", "rank", b"rank", "refresh_page", b"refresh_page", "refresh_special_cell", b"refresh_special_cell", "relate_tab", b"relate_tab", "relates", b"relates", "reply_preface", b"reply_preface", "req_user", b"req_user", "season", b"season", "share_subtitle", b"share_subtitle", "short_link", b"short_link", "special_cell", b"special_cell", "special_cell_new", b"special_cell_new", "staff", b"staff", "sticker", b"sticker", "t_icon", b"t_icon", "tab", b"tab", "tag", b"tag", "tf_panel_customized", b"tf_panel_customized", "ugc_season", b"ugc_season", "up_act", b"up_act", "up_like_img", b"up_like_img", "user_garb", b"user_garb", "video_source", b"video_source", "vip_active", b"vip_active"]) -> None: ...

global___ViewReply = ViewReply

@typing_extensions.final
class ViewReq(google.protobuf.message.Message):
    """视频页详情页-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    AD_EXTRA_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    PAGE_VERSION_FIELD_NUMBER: builtins.int
    BIZ_EXTRA_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    RELATES_PAGE_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    IN_FEED_PLAY_FIELD_NUMBER: builtins.int
    PLAY_MODE_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    REFRESH_FIELD_NUMBER: builtins.int
    REFRESH_NUM_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid(av/bv任选其一)"""
    bvid: builtins.str
    """稿件bvid(av/bv任选其一)"""
    trackid: builtins.str
    """AI trackid"""
    ad_extra: builtins.str
    """广告扩展数据"""
    qn: builtins.int
    """清晰度(旧版)"""
    fnver: builtins.int
    """流版本(旧版)"""
    fnval: builtins.int
    """流类型(旧版)"""
    force_host: builtins.int
    """是否强制使用域名(旧版)"""
    fourk: builtins.int
    """是否允许4K(旧版)"""
    spmid: builtins.str
    """当前页面spm"""
    from_spmid: builtins.str
    """上一页面spm"""
    autoplay: builtins.int
    """"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """视频秒开参数"""
    page_version: builtins.str
    """"""
    biz_extra: builtins.str
    """"""
    device_type: builtins.int
    """"""
    relates_page: builtins.int
    """"""
    session_id: builtins.str
    """"""
    in_feed_play: builtins.int
    """"""
    play_mode: builtins.str
    """"""
    @property
    def pagination(self) -> bilireq.grpc.protos.bilibili.pagination.pagination_pb2.Pagination:
        """"""
    refresh: builtins.int
    """"""
    refresh_num: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        trackid: builtins.str = ...,
        ad_extra: builtins.str = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        autoplay: builtins.int = ...,
        player_args: bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        page_version: builtins.str = ...,
        biz_extra: builtins.str = ...,
        device_type: builtins.int = ...,
        relates_page: builtins.int = ...,
        session_id: builtins.str = ...,
        in_feed_play: builtins.int = ...,
        play_mode: builtins.str = ...,
        pagination: bilibili.pagination.pagination_pb2.Pagination | None = ...,
        refresh: builtins.int = ...,
        refresh_num: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "player_args", b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra", b"ad_extra", "aid", b"aid", "autoplay", b"autoplay", "biz_extra", b"biz_extra", "bvid", b"bvid", "device_type", b"device_type", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "from", b"from", "from_spmid", b"from_spmid", "in_feed_play", b"in_feed_play", "page_version", b"page_version", "pagination", b"pagination", "play_mode", b"play_mode", "player_args", b"player_args", "qn", b"qn", "refresh", b"refresh", "refresh_num", b"refresh_num", "relates_page", b"relates_page", "session_id", b"session_id", "spmid", b"spmid", "trackid", b"trackid"]) -> None: ...

global___ViewReq = ViewReq

@typing_extensions.final
class ViewTagReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPECIAL_CELL_NEW_FIELD_NUMBER: builtins.int
    MATERIAL_LEFT_FIELD_NUMBER: builtins.int
    @property
    def special_cell_new(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SpecialCell]:
        """"""
    @property
    def material_left(self) -> global___MaterialLeft:
        """"""
    def __init__(
        self,
        *,
        special_cell_new: collections.abc.Iterable[global___SpecialCell] | None = ...,
        material_left: global___MaterialLeft | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["material_left", b"material_left"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["material_left", b"material_left", "special_cell_new", b"special_cell_new"]) -> None: ...

global___ViewTagReply = ViewTagReply

@typing_extensions.final
class ViewTagReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    bvid: builtins.str
    """"""
    cid: builtins.int
    """"""
    spmid: builtins.str
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        bvid: builtins.str = ...,
        cid: builtins.int = ...,
        spmid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "bvid", b"bvid", "cid", b"cid", "spmid", b"spmid"]) -> None: ...

global___ViewTagReq = ViewTagReq

@typing_extensions.final
class Vip(google.protobuf.message.Message):
    """会员信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    DUE_REMARK_FIELD_NUMBER: builtins.int
    ACCESS_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_WARN_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    type: builtins.int
    """会员类型"""
    due_date: builtins.int
    """到期时间"""
    due_remark: builtins.str
    """"""
    access_status: builtins.int
    """"""
    vip_status: builtins.int
    """会员状态"""
    vip_status_warn: builtins.str
    """"""
    theme_type: builtins.int
    """"""
    @property
    def label(self) -> global___VipLabel:
        """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        due_date: builtins.int = ...,
        due_remark: builtins.str = ...,
        access_status: builtins.int = ...,
        vip_status: builtins.int = ...,
        vip_status_warn: builtins.str = ...,
        theme_type: builtins.int = ...,
        label: global___VipLabel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_status", b"access_status", "due_date", b"due_date", "due_remark", b"due_remark", "label", b"label", "theme_type", b"theme_type", "type", b"type", "vip_status", b"vip_status", "vip_status_warn", b"vip_status_warn"]) -> None: ...

global___Vip = Vip

@typing_extensions.final
class VipLabel(google.protobuf.message.Message):
    """会员类型标签"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LABEL_THEME_FIELD_NUMBER: builtins.int
    path: builtins.str
    """"""
    text: builtins.str
    """"""
    label_theme: builtins.str
    """"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        text: builtins.str = ...,
        label_theme: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["label_theme", b"label_theme", "path", b"path", "text", b"text"]) -> None: ...

global___VipLabel = VipLabel
